# -*- coding: utf-8 -*-

__author__ = 'Konstantin Bezdenezhnykh'

import re
from time import time
import json

import sklearn.feature_extraction.text
from sklearn.preprocessing import LabelEncoder
from sklearn import cross_validation
from sklearn.pipeline import Pipeline
from sklearn.grid_search import GridSearchCV
from sklearn.linear_model import PassiveAggressiveClassifier
from sklearn.linear_model import Perceptron


def prepare(text):
    text = text.lower()
    # remove URLs
    text = re.sub(
        r'(?i)\b((?:https?://|www\d{0,3}[.]|[a-z0-9.\-]+[.][a-z]{2,4}/)(?:[^\s()<>]+|\(([^\s()<>]+|(\([^\s()<>]+\)))*\))+(?:\(([^\s()<>]+|(\([^\s()<>]+\)))*\)|[^\s`!()\[\]{};:\'".,<>?«»“”‘’]))',
        '', text)
    # text = re.sub(r'([#@]\S+', '', text) #hashtags and @users
    text = re.sub(r"[\)]+", ')', text)  # for :))))) smiles, lots of them
    text = re.sub(r"[\(]+", '(', text)  # same for :((
    #text = nltk.SnowballStemmer('russian').stem(unicode(text)) # utter shit
    #print text
    return text


class SentimentAnalyzer:
    def __init__(self):
        self.le = LabelEncoder()
        self.classifier = None

    #trainer of classifier (mandatory)
    def train(self, training_corpus, at_home=False):
        t = time()
        tt = t
        n = len(training_corpus)
        print 'Started training on %d tweets' % n
        tweets = [prepare(tweet['text']) for tweet in training_corpus]
        marks = [tweet['polarity'] for tweet in training_corpus]
        self.le.fit(marks)
        x = tweets
        y = self.le.transform(marks)
        cv10 = cross_validation.StratifiedKFold(y, n_folds=10)
        print 'Processed tweets in %0.3fs' % (time() - t)
        t = time()
        if at_home:
            # parameter bruteforce for each pipeline on cv10, best pipeline selection, printing
            pipelines = [('PassiveAgressive',
                          Pipeline([('vect', sklearn.feature_extraction.text.CountVectorizer()),
                                    ('tfidf', sklearn.feature_extraction.text.TfidfTransformer()),
                                    ('clf', PassiveAggressiveClassifier(n_iter=10))]),
                          {'vect__max_df': (0.5, 0.75, 1.0, ),
                           'vect__analyzer': ('char_wb', 'word', 'char', ),
                           'vect__max_features': (None, 5000, 1000, 10000, ),
                           'vect__ngram_range': ((1, 10), (1, 1), (1, 2), ),
                           'tfidf__norm': ('l2', 'l1', ),
                           'clf__n_iter': (50, 10, 100, ),
                           }),

                         ('Perceptron',
                          Pipeline([('vect', sklearn.feature_extraction.text.CountVectorizer()),
                                    ('tfidf', sklearn.feature_extraction.text.TfidfTransformer()),
                                    ('clf', Perceptron(n_iter=10))]),
                          {'vect__max_df': (0.5, 0.75, 1.0, ),
                           'vect__analyzer': ('char_wb', 'word', 'char', ),
                           'vect__ngram_range': ((1, 10), (1, 1), (1, 2), ),
                           'tfidf__norm': ('l2', 'l1', ),
                           'clf__alpha': (0.00001, 0.0000001, ),
                           'clf__n_iter': (50, 10, 100, ),
                           }),
                         ]
            results = []
            for clf in pipelines:
                print 'Cross validating and grid searching ', clf[0]
                cl = GridSearchCV(clf[1], param_grid=clf[2], cv=cv10, n_jobs=4, verbose=1)
                cl.fit(x, y)
                print 'Cross validating ', clf[0]
                scores = cross_validation.cross_val_score(cl.best_estimator_, x, y, cv=cv10)
                score = (cl.best_estimator_, sum(scores) / len(scores))
                results.append(score)
                print cl.best_estimator_
                print 'Scores = ', scores
                print 'Avg score = ', score[1]
                print 'CV done in %0.3fs' % (time() - t)
                t = time()

            best_res = max(results, key=lambda r: r[1])
            #print results
            print 'Best = ', best_res[0]
            print 'Best score in CV = ', best_res[1]
            print 'Best classifier found in %0.3fs' % (time() - tt)
            t = time()
            self.classifier = best_res[0]
        else:
            # train for markup server
            self.classifier = Pipeline([
                ('vect', sklearn.feature_extraction.text.CountVectorizer(analyzer='char_wb',
                                                                         max_df=0.5,
                                                                         max_features=None,
                                                                         ngram_range=(1, 10))),
                ('tfidf', sklearn.feature_extraction.text.TfidfTransformer(norm='l2')),
                ('clf', PassiveAggressiveClassifier(n_iter=50))])
            # for debug
            #scores = cross_validation.cross_val_score(self.classifier, x, y, cv=cv10)
            #print scores
            #print sum(scores) / len(scores)
        self.classifier.fit(x, y)
        print 'Trained on full set in %0.3fs' % (time() - t)
        print 'Total time: %0.3fs' % (time() - tt)

    #returns sentiment score of input text (mandatory)
    def getClasses(self, texts):
        tweets = [prepare(text) for text in texts]
        res = self.le.inverse_transform(self.classifier.predict(tweets))
        return [ans.encode('ascii') for ans in res]


if __name__ == '__main__':
    t0 = time()
    print u'so print, much code, проверка юникода'
    path_to_training_corpus = './tweets_1.json'
    analyzer = SentimentAnalyzer()
    corpus = json.load(open(path_to_training_corpus))
    print 'Tweets loaded in %0.3fs' % (time() - t0)
    analyzer.train(corpus, at_home=False)