# encoding: UTF-8
from __future__ import division, absolute_import, print_function, unicode_literals

import sys

import sklearn.pipeline
import sklearn.feature_extraction
import sklearn.feature_extraction.text
import sklearn.feature_selection
import sklearn.linear_model
import sklearn.grid_search

from . import extractor

PARALLEL = True
DISABLE_GRID = False

PARALLEL = False
DISABLE_GRID = True

def construct_pipeline():
    steps = [
        ("extractor", extractor.Extractor()),
        ("hasher", sklearn.feature_extraction.FeatureHasher(input_type="pair", non_negative=True)),
#       ("pruner", util.FeaturePruner())),
        ("tfidf", sklearn.feature_extraction.text.TfidfTransformer()),
#       ("normalizer", sklearn.preprocessing.Normalizer(copy=False)),
        ("clf", sklearn.linear_model.SGDClassifier(penalty="elasticnet", l1_ratio=0.1, n_iter=10)),
#       ("clf", sklearn.linear_model.PassiveAggressiveClassifier(n_iter=10),
#       ("clf", sklearn.linear_model.RidgeClassifier()),
    ]

    pipeline = sklearn.pipeline.Pipeline(
        steps=steps
    )

    if DISABLE_GRID:
        #print("Warning! Grid search is disabled", file=sys.stderr)
        return pipeline
    else:
        grid_params = {
            "extractor__ngram_weight": [0.3, 0.4],
            "extractor__smile_weight": [2.0, 2.5],
            #"extractor__hashtag_weight": [1.0, 1.25],
            #"extractor__capslock_weight":  [1.0, 2.0],
            "extractor__punctuation_weight": [0.75, 1.0],
            #"extractor__url_weight": [0.0, 1.0],
            "clf__alpha": [0.0001, 0.00005],
            "clf__l1_ratio": [0.1, 0.0],
        }
        njobs = -1
        if not PARALLEL:
            print("Warning! Parallel execution is disabled", file=sys.stderr)
            njobs = 1

        grid_search = sklearn.grid_search.GridSearchCV(pipeline, grid_params, n_jobs=njobs, cv=4)
        return grid_search
