# encoding: UTF-8
from __future__ import division, absolute_import, print_function

import urlparse
import re
import unicodedata

def make_remover(callback, ret=""):
    # returns a function that can passed to re.sub
    def repl(matchobj):
        if callback:
            callback(matchobj.group(0))
        return ret
    return repl

URL_PATTERN1 = re.compile("(?:http|https|ftp|mailto):[^ ]*", re.UNICODE | re.IGNORECASE)
#URL_PATTERN2 = re.compile("pic\.twitter\.com/[^ ]*", re.UNICODE | re.IGNORECASE)
URL_PATTERN3 = re.compile("[a-z.]+\.(?:ru|com|org|net)/[^ ]*", re.UNICODE | re.IGNORECASE)

AT_PATTERN = re.compile("@[^ ]*", re.UNICODE | re.IGNORECASE)
HASHTAG_PATTERN = re.compile("#([^ ]*)", re.UNICODE | re.IGNORECASE)

OTHER_SMILIES = re.compile(
    "(?:" + "|".join(map(re.escape, [
        "^_^",
        "^^",
        "o_o",
        "0_o",
        "0_0",
        "<_<",
        ">_>",
        ">_<",
        "X_X",
        "T_T",
        "-_-",
        "|_|",
        "=_=",
        "<3",
        ":3",
        "=/",
        "=\\",
        ":/",
        ":\\",
    ])) + ")",
    re.UNICODE | re.IGNORECASE
)

# :-), :), :D, :-D, etc.
# TODO =), =( 
HAPPY_SMILE_PATTERN = re.compile(r"(?:[:;][-=]?|=)[)D]+", re.UNICODE | re.IGNORECASE)
SAD_SMILE_PATTERN = re.compile(r"(?:[:;][-=]?|=)[(]+", re.UNICODE | re.IGNORECASE)

MATCHING_PARENTHESES = re.compile(r"[(](.*)[)]", re.UNICODE | re.IGNORECASE)

OPEN_PARENTHESES = re.compile(r"[(]+", re.UNICODE | re.IGNORECASE)
CLOSE_PARENTHESES = re.compile("[)]+", re.UNICODE | re.IGNORECASE)

PUNCTUATION_PATTERN = re.compile("[.!?,]+", re.UNICODE | re.IGNORECASE)

REPEATED_CHARACTERS = re.compile(r"(\w)\1+", re.UNICODE | re.IGNORECASE)

SYMBOLS_TO_JUST_REMOVE = re.compile(ur"[^а-яёa-z0-9]", re.UNICODE | re.IGNORECASE)

TRANSLATE_TABLE = {
    
}

class TweetData(object):
    def __init__(self):
        self.urls = []
        self.mentions = []
        self.hashtags = []

        self.other_smilies = []
        self.happy_smilies = []
        self.sad_smilies = []

        self.punctuation = []
        
    __slots__ = [
        "raw_text",
        "text", 
        "urls", 
        "mentions", 
        "hashtags",
        "other_smilies",
        "happy_smilies",
        "sad_smilies",
        "punctuation",
    ]

def preprocess_tweet(text):
    data = TweetData()
    data.raw_text = text
    
    def hashtag_repl(matchobj):
        data.hashtags.append(matchobj.group(0))
        return matchobj.group(1)

    text = unicodedata.normalize("NFKC", text)
    text = text.strip()
    text = URL_PATTERN1.sub(make_remover(data.urls.append), text)
    #text = URL_PATTERN2.sub(make_remover(data.urls.append), text)
    text = URL_PATTERN3.sub(make_remover(data.urls.append), text)
    text = AT_PATTERN.sub(make_remover(data.mentions.append), text)
    text = HASHTAG_PATTERN.sub(hashtag_repl, text)
    text = OTHER_SMILIES.sub(make_remover(data.other_smilies.append, " "), text)
    text = HAPPY_SMILE_PATTERN.sub(make_remover(data.happy_smilies.append, " "), text)
    text = SAD_SMILE_PATTERN.sub(make_remover(data.sad_smilies.append, " "), text)

    subs_made = 1
    while subs_made:
        text, subs_made = MATCHING_PARENTHESES.subn(r"\1", text)

    text = OPEN_PARENTHESES.sub(make_remover(data.sad_smilies.append, " "), text)
    text = CLOSE_PARENTHESES.sub(make_remover(data.happy_smilies.append, " "), text)

    # use no more than 6 symbols of consecutive punctuation
    text = PUNCTUATION_PATTERN.sub(make_remover(lambda x: data.punctuation.append(x[:6]), " "), text)

    # replace consecutive letters 
    # although it increases chances of collisions, it also 
    # fixes typos and YEEEEELING 
    text = REPEATED_CHARACTERS.sub(r"\1", text)

    text = SYMBOLS_TO_JUST_REMOVE.sub(" ", text)

    #print(data.raw_text)
    #print(text)
    #print()

    data.text = text
    return data

WORD_PATTERN = re.compile("[^\W\d]+$", re.UNICODE)
def check_word(word):
    return WORD_PATTERN.match(word) is not None

RUSSIAN_WORD_PATTERN = re.compile(u"^[а-я]+$", re.UNICODE | re.IGNORECASE)
def check_russian_word(word):
    return RUSSIAN_WORD_PATTERN.match(word) is not None

def parse_url(url):
    try:
        res = urlparse.urlparse(url)
        if res.scheme == "":
            res = urlparse.urlparse("http://" + url)
        if res.scheme != "":
            return res
    except Exception:
        pass
        raise
    return None
