# encoding: UTF-8
from __future__ import division, absolute_import, print_function, unicode_literals

import functools

import numpy as np

import nltk.stem.snowball

import sklearn.feature_selection.base

class CachedRussianStemmer(nltk.stem.snowball.RussianStemmer):
    def __init__(self, *args, **kwargs):
        super(CachedRussianStemmer, self).__init__(*args, **kwargs)

        self.__cache = {}
        self.__cache_size = 5000

    def set_cache_size(self, size):
        self.__cache_size = size
        
    def stem(self, word):
        cache = self.__cache
        cache_size = self.__cache_size

        value = cache.get(word)
        if value is None:
            value = super(CachedRussianStemmer, self).stem(word)

            while len(cache) > cache_size:
                cache.popitem()

            cache[word] = value

        return value

class FeaturePruner(sklearn.feature_selection.base.SelectorMixin):
    def __init__(self, threshold=.0):
        self.threshold = threshold

    def fit(self, X, y):
        non_zero = np.asarray(X.sum(0) > self.threshold).squeeze()
        
        #print("Total features: {}, non-zero features: {}".format(X.shape[1], np.count_nonzero(X.sum(0) > 0)))

        self.__mask = non_zero
        return self

    def _get_support_mask(self):
        return self.__mask 
