#!/usr/bin/env python2
# encoding: UTF-8
from __future__ import division, absolute_import, print_function, unicode_literals

import threading
import json

from Tkinter import *
from ttk import *

import tkFileDialog 

import SentimentAnalyzer

class TweetMarkup(Tk):
    def __init__(self):
        Tk.__init__(self)

        # misc.
        self.analyzer = None
        self.main_thread_id = threading.current_thread().ident

        # ui

        self.create_menu()
        
        self.columnconfigure(0, weight=1)
        self.rowconfigure(0, weight=1)
        self.rowconfigure(1, weight=0)
        self.rowconfigure(2, weight=1)

        self.button = Button(self, text="Classify", command=self.classify)
        self.button.grid(sticky=W+E, column=0, row=0)

        self.entry = Text(self)
        self.entry.grid(sticky=W+E+N+S, column=0, row=1)
        
        self.statusbar = Label(self)
        self.statusbar.grid(sticky=W, column=0, row=2)


    def create_menu(self):
        self.option_add("*tearOff", False)

        menubar = Menu(self)
        self["menu"] = menubar

        menubar.add_cascade(menu=self.create_menu_train(menubar), label="Train")

    def create_menu_train(self, root=None):
        def train():
            f = tkFileDialog.askopenfile(defaultextension=".json", filetypes=[("JSON", ".json")])
            if not f: return

            def run():
                try:
                    with f:
                        self.set_status("Loading JSON data...")
                        corpus = json.load(f)
                        self.set_status("Training model...")
                        analyzer = SentimentAnalyzer.SentimentAnalyzer()
                        analyzer.train(corpus)
                except:
                    setl.set_status("Error occured")
                    raise
                else:
                    self.analyzer = analyzer
                    self.set_status("Done")

            threading.Thread(target=run).start()
        
        menu = Menu(root)
        menu.add_command(label="Train...", command=train)
        return menu

    def set_status(self, text):
        f = lambda: self.statusbar.configure(text=text)

        if threading.current_thread().ident == self.main_thread_id:
            f()
        else:
            self.after(0, f)

    def classify(self):
        if not self.analyzer:
            self.set_status("Model is not trained")
            return

        text = self.entry.get("0.0", END)

        self.set_status("Analyzing...")

        polarity = self.analyzer.getClasses([text])[0]

        self.set_status(polarity)

def main():
    root = TweetMarkup()
    root.mainloop()

if __name__ == "__main__":
    main()
