#coding: utf-8
'''
Created on 10 mart 2014.

@author: Ulyanov A
'''
       
 
#from sklearn import svm
#from sklearn import datasets


import json
import nltk
from numpy import *
from nltk.stem import SnowballStemmer
from sklearn import cross_validation, svm
from sklearn.ensemble import RandomForestClassifier 


class SentimentAnalyzer:
    
    VOCABULARY_LEN = 2301
    vocabulary  = {
        u'иб' : 0,           
        u'!' : 1,
        u'в' : 2,
        u'и' : 3,
        u'не' : 4,
        u'на' : 5,
        u'я' : 6,
        u'с' : 7,
        u'что' : 8,
        u'эт' : 9,
        u'как' : 10,
        u'а' : 11,
        u'так' : 12,
        u'за' : 13,
        u'по' : 14,
        u'у' : 15,
        u'то' : 16,
        u'все' : 17,
        u'мен' : 18,
        u'из' : 19,
        u'к' : 20,
        u'мо' : 21,
        u'был' : 22,
        u'когд' : 23,
        u'сам' : 24,
        u'он' : 25,
        u'сегодн' : 26,
        u'ден' : 27,
        u'сво' : 28,
        u'но' : 29,
        u'мне' : 30,
        u'котор' : 31,
        u'о' : 32,
        u'же' : 33,
        u'уж' : 34,
        u'очен' : 35,
        u'ещ' : 36,
        u'нов' : 37,
        u'для' : 38,
        u'от' : 39,
        u'прост' : 40,
        u'год' : 41,
        u'росс' : 42,
        u'до' : 43,
        u'хорош' : 44,
        u'люд' : 45,
        u'человек' : 46,
        u'ты' : 47,
        u'ненавиж' : 48,
        u'ну' : 49,
        u'наш' : 50,
        u'дом' : 51,
        u'больш' : 52,
        u'будет' : 53,
        u'перв' : 54,
        u'одн' : 55,
        u'мы' : 56,
        u'себ' : 57,
        u'ест' : 58,
        u'раз' : 59,
        u'жизн' : 60,
        u'лучш' : 61,
        u'теб' : 62,
        u'любл' : 63,
        u'соч' : 64,
        u'да' : 65,
        u'чем' : 66,
        u'нет' : 67,
        u'крут' : 68,
        u'всем' : 69,
        u'бы' : 70,
        u'над' : 71,
        u'чтоб' : 72,
        u'есл' : 73,
        u'москв' : 74,
        u'тольк' : 75,
        u'даж' : 76,
        u'ег' : 77,
        u'спасиб' : 78,
        u'врем' : 79,
        u'мог' : 80,
        u'нача' : 81,
        u'друг' : 82,
        u'сейчас' : 83,
        u'час' : 84,
        u'лет' : 85,
        u'мног' : 86,
        u'отличн' : 87,
        u'олимпиад' : 88,
        u'утр' : 89,
        u'вы' : 90,
        u'е' : 91,
        u'кажд' : 92,
        u'там' : 93,
        u'вот' : 94,
        u'хот' : 95,
        u'тепер' : 96,
        u'кто' : 97,
        u'дела' : 98,
        u'ур' : 99,
        u'мест' : 100,
        u'новост' : 101,
        u'говор' : 102,
        u'работ' : 103,
        u'сдела' : 104,
        u'посл' : 105,
        u'тут' : 106,
        u'стал' : 107,
        u'мир' : 108,
        u'дел' : 109,
        u'хоч' : 110,
        u'последн' : 111,
        u'игр' : 112,
        u'стран' : 113,
        u'можн' : 114,
        u'со' : 115,
        u'вообщ' : 116,
        u'про' : 117,
        u'плох' : 118,
        u'рад' : 119,
        u'украин' : 120,
        u'скор' : 121,
        u'завтр' : 122,
        u'пот' : 123,
        u'может' : 124,
        u'во' : 125,
        u'нужн' : 126,
        u'чита' : 127,
        u'всех' : 128,
        u'фильм' : 129,
        u'бол' : 130,
        u'без' : 131,
        u'под' : 132,
        u'получ' : 133,
        u'этот' : 134,
        u'ноч' : 135,
        u'недел' : 136,
        u'буд' : 137,
        u'ужасн' : 138,
        u'смотр' : 139,
        u'где' : 140,
        u'хочет' : 141,
        u'крым' : 142,
        u'вечер' : 143,
        u'всегд' : 144,
        u'ил' : 145,
        u'прекрасн' : 146,
        u'дума' : 147,
        u'приятн' : 148,
        u'вас' : 149,
        u'российск' : 150,
        u'их' : 151,
        u'нич' : 152,
        u'погод' : 153,
        u'любим' : 154,
        u'дня' : 155,
        u'быт' : 156,
        u'пок' : 157,
        u'город' : 158,
        u'настроен' : 159,
        u'суд' : 160,
        u'люб' : 161,
        u'ни' : 162,
        u'нас' : 163,
        u'добр' : 164,
        u'поч' : 165,
        u'слов' : 166,
        u'куп' : 167,
        u'школ' : 168,
        u'твиттер' : 169,
        u'красив' : 170,
        u'нам' : 171,
        u'русск' : 172,
        u'втор' : 173,
        u'сказа' : 174,
        u'путин' : 175,
        u'олимпийск' : 176,
        u'сша' : 177,
        u'тем' : 178,
        u'опя' : 179,
        u'два' : 180,
        u'блин' : 181,
        u'улиц' : 182,
        u'нибуд' : 183,
        u'друз' : 184,
        u'прям' : 185,
        u'снов' : 186,
        u'побед' : 187,
        u'работа' : 188,
        u'один' : 189,
        u'никогд' : 190,
        u'начина' : 191,
        u'чувств' : 192,
        u'через' : 193,
        u'сборн' : 194,
        u'классн' : 195,
        u'наконец' : 196,
        u'игра' : 197,
        u'телефон' : 198,
        u'прав' : 199,
        u'рубл' : 200,
        u'совс' : 201,
        u'понима' : 202,
        u'девушк' : 203,
        u'золот' : 204,
        u'хокк' : 205,
        u'пар' : 206,
        u'оста' : 207,
        u'всег' : 208,
        u'главн' : 209,
        u'ли' : 210,
        u'спат' : 211,
        u'вопрос' : 212,
        u'грустн' : 213,
        u'мам' : 214,
        u'счастлив' : 215,
        u'ваш' : 216,
        u'вам' : 217,
        u'им' : 218,
        u'сто' : 219,
        u'бес' : 220,
        u'твит' : 221,
        u'президент' : 222,
        u'минут' : 223,
        u'компан' : 224,
        u'откр' : 225,
        u'будут' : 226,
        u'вмест' : 227,
        u'писа' : 228,
        u'при' : 229,
        u'рук' : 230,
        u'интернет' : 231,
        u'истор' : 232,
        u'дорог' : 233,
        u'метр' : 234,
        u'сем' : 235,
        u'замечательн' : 236,
        u'обожа' : 237,
        u'черт' : 238,
        u'нашл' : 239,
        u'три' : 240,
        u'дне' : 241,
        u'скольк' : 242,
        u'прошл' : 243,
        u'нельз' : 244,
        u'песн' : 245,
        u'дожд' : 246,
        u'отвратительн' : 247,
        u'почт' : 248,
        u'студент' : 249,
        u'тог' : 250,
        u'книг' : 251,
        u'пор' : 252,
        u'здоров' : 253,
        u'сильн' : 254,
        u'вещ' : 255,
        u'туп' : 256,
        u'интересн' : 257,
        u'рожден' : 258,
        u'ед' : 259,
        u'счаст' : 260,
        u'поня' : 261,
        u'том' : 262,
        u'времен' : 263,
        u'цел' : 264,
        u'об' : 265,
        u'кажет' : 266,
        u'видел' : 267,
        u'узна' : 268,
        u'матч' : 269,
        u'пуст' : 270,
        u'част' : 271,
        u'свет' : 272,
        u'трет' : 273,
        u'ем' : 274,
        u'давн' : 275,
        u'весн' : 276,
        u'ужас' : 277,
        u'тож' : 278,
        u'заб' : 279,
        u'ход' : 280,
        u'реш' : 281,
        u'зна' : 282,
        u'гор' : 283,
        u'открыт' : 284,
        u'прот' : 285,
        u'ве' : 286,
        u'м' : 287,
        u'момент' : 288,
        u'выигра' : 289,
        u'назад' : 290,
        u'возможн' : 291,
        u'выход' : 292,
        u'смотрет' : 293,
        u'поздравля' : 294,
        u'доста' : 295,
        u'суперкритик' : 296,
        u'март' : 297,
        u'владимир' : 298,
        u'голов' : 299,
        u'слуша' : 300,
        u'пришл' : 301,
        u'феврал' : 302,
        u'сер' : 303,
        u'имен' : 304,
        u'уч' : 305,
        u'нрав' : 306,
        u'мужик' : 307,
        u'весел' : 308,
        u'снег' : 309,
        u'счита' : 310,
        u'тепл' : 311,
        u'ребят' : 312,
        u'хотел' : 313,
        u'тот' : 314,
        u'выходн' : 315,
        u'ког' : 316,
        u'музык' : 317,
        u'ж' : 318,
        u'перед' : 319,
        u'мгу' : 320,
        u'ряд' : 321,
        u'похож' : 322,
        u'совет' : 323,
        u'отст' : 324,
        u'кстат' : 325,
        u'след' : 326,
        u'знает' : 327,
        u'мечт' : 328,
        u'них' : 329,
        u'полн' : 330,
        u'вчер' : 331,
        u'приеха' : 332,
        u'пол' : 333,
        u'чег' : 334,
        u'особен' : 335,
        u'дет' : 336,
        u'язык' : 337,
        u'готов' : 338,
        u'всю' : 339,
        u'нескольк' : 340,
        u'вед' : 341,
        u'пап' : 342,
        u'любов' : 343,
        u'парн' : 344,
        u'врод' : 345,
        u'т' : 346,
        u'машин' : 347,
        u'говн' : 348,
        u'зач' : 349,
        u'сесс' : 350,
        u'закрыт' : 351,
        u'никак' : 352,
        u'ответ' : 353,
        u'радост' : 354,
        u'иногд' : 355,
        u'ненавист' : 356,
        u'чут' : 357,
        u'сайт' : 358,
        u'созда' : 359,
        u'центр' : 360,
        u'месяц' : 361,
        u'должн' : 362,
        u'понрав' : 363,
        u'печал' : 364,
        u'проект' : 365,
        u'зде' : 366,
        u'офиген' : 367,
        u'продолжа' : 368,
        u'мал' : 369,
        u'автобус' : 370,
        u'понедельник' : 371,
        u'сезон' : 372,
        u'вернул' : 373,
        u'вид' : 374,
        u'тво' : 375,
        u'жит' : 376,
        u'народ' : 377,
        u'зимн' : 378,
        u'сход' : 379,
        u'очередн' : 380,
        u'молодц' : 381,
        u'вперв' : 382,
        u'нег' : 383,
        u'груст' : 384,
        u'сред' : 385,
        u'получа' : 386,
        u'медал' : 387,
        u'невероятн' : 388,
        u'быстр' : 389,
        u'важн' : 390,
        u'детств' : 391,
        u'билет' : 392,
        u'занима' : 393,
        u'будт' : 394,
        u'вод' : 395,
        u'нос' : 396,
        u'никт' : 397,
        u'половин' : 398,
        u'сил' : 399,
        u'киев' : 400,
        u'солнц' : 401,
        u'оказыва' : 402,
        u'встрет' : 403,
        u'войн' : 404,
        u'летн' : 405,
        u'концерт' : 406,
        u'хуж' : 407,
        u'вер' : 408,
        u'урок' : 409,
        u'мно' : 410,
        u'журналист' : 411,
        u'плющенк' : 412,
        u'слишк' : 413,
        u'стат' : 414,
        u'брат' : 415,
        u'праздник' : 416,
        u'власт' : 417,
        u'групп' : 418,
        u'днем' : 419,
        u'украинск' : 420,
        u'пошл' : 421,
        u'керлинг' : 422,
        u'сраз' : 423,
        u'яндекс' : 424,
        u'решен' : 425,
        u'доллар' : 426,
        u'будущ' : 427,
        u'пойд' : 428,
        u'потеря' : 429,
        u'желан' : 430,
        u'страшн' : 431,
        u'окн' : 432,
        u'мил' : 433,
        u'тысяч' : 434,
        u'команд' : 435,
        u'конечн' : 436,
        u'развит' : 437,
        u'посмотрел' : 438,
        u'идет' : 439,
        u'написа' : 440,
        u'лен' : 441,
        u'магазин' : 442,
        u'церемон' : 443,
        u'лент' : 444,
        u'рф' : 445,
        u'проблем' : 446,
        u'стар' : 447,
        u'суббот' : 448,
        u'те' : 449,
        u'жал' : 450,
        u'дава' : 451,
        u'чемпион' : 452,
        u'ид' : 453,
        u'смотрел' : 454,
        u'взял' : 455,
        u'супер' : 456,
        u'нормальн' : 457,
        u'ко' : 458,
        u'законч' : 459,
        u'сдал' : 460,
        u'кот' : 461,
        u'экзам' : 462,
        u'приход' : 463,
        u'ок' : 464,
        u'идт' : 465,
        u'бел' : 466,
        u'печальн' : 467,
        u'найт' : 468,
        u'блят' : 469,
        u'голос' : 470,
        u'шикарн' : 471,
        u'женщин' : 472,
        u'видим' : 473,
        u'ожида' : 474,
        u'запрет' : 475,
        u'бронз' : 476,
        u'александр' : 477,
        u'ум' : 478,
        u'некотор' : 479,
        u'сук' : 480,
        u'пиздец' : 481,
        u'никуд' : 482,
        u'две' : 483,
        u'зачет' : 484,
        u'родн' : 485,
        u'област' : 486,
        u'общ' : 487,
        u'реальн' : 488,
        u'вконтакт' : 489,
        u'ним' : 490,
        u'парен' : 491,
        u'душ' : 492,
        u'лекц' : 493,
        u'всяк' : 494,
        u'правильн' : 495,
        u'сид' : 496,
        u'меньш' : 497,
        u'правительств' : 498,
        u'бесплатн' : 499,
        u'ком' : 500,
        u'гонк' : 501,
        u'хвата' : 502,
        u'руб' : 503,
        u'фотк' : 504,
        u'пят' : 505,
        u'появ' : 506,
        u'куч' : 507,
        u'поэт' : 508,
        u'солнышк' : 509,
        u'велик' : 510,
        u'сиж' : 511,
        u'земл' : 512,
        u'подар' : 513,
        u'назван' : 514,
        u'стольк' : 515,
        u'сет' : 516,
        u'поезд' : 517,
        u'фотограф' : 518,
        u'прошел' : 519,
        u'пут' : 520,
        u'поездк' : 521,
        u'смен' : 522,
        u'равн' : 523,
        u'надоел' : 524,
        u'ран' : 525,
        u'мужчин' : 526,
        u'зим' : 527,
        u'окол' : 528,
        u'воскресен' : 529,
        u'дан' : 530,
        u'отношен' : 531,
        u'черн' : 532,
        u'ночн' : 533,
        u'курс' : 534,
        u'американск' : 535,
        u'айфон' : 536,
        u'сидет' : 537,
        u'единствен' : 538,
        u'девочк' : 539,
        u'лиш' : 540,
        u'лиц' : 541,
        u'ча' : 542,
        u'закр' : 543,
        u'жду' : 544,
        u'план' : 545,
        u'глаз' : 546,
        u'конц' : 547,
        u'господ' : 548,
        u'честн' : 549,
        u'банк' : 550,
        u'успех' : 551,
        u'попа' : 552,
        u'постав' : 553,
        u'обидн' : 554,
        u'перевод' : 555,
        u'подряд' : 556,
        u'знаком' : 557,
        u'свобод' : 558,
        u'провод' : 559,
        u'серебр' : 560,
        u'сегодняшн' : 561,
        u'быва' : 562,
        u'норм' : 563,
        u'повер' : 564,
        u'кана' : 565,
        u'видет' : 566,
        u'ощущен' : 567,
        u'небольш' : 568,
        u'биатлон' : 569,
        u'тех' : 570,
        u'каникул' : 571,
        u'выгляд' : 572,
        u'болет' : 573,
        u'миллион' : 574,
        u'универ' : 575,
        u'дик' : 576,
        u'раньш' : 577,
        u'собра' : 578,
        u'активн' : 579,
        u'верс' : 580,
        u'официальн' : 581,
        u'министр' : 582,
        u'программ' : 583,
        u'правд' : 584,
        u'пятниц' : 585,
        u'пресс' : 586,
        u'смысл' : 587,
        u'страниц' : 588,
        u'четыр' : 589,
        u'красот' : 590,
        u'пыта' : 591,
        u'московск' : 592,
        u'довольн' : 593,
        u'класс' : 594,
        u'спрос' : 595,
        u'регион' : 596,
        u'станов' : 597,
        u'футбол' : 598,
        u'взят' : 599,
        u'б' : 600,
        u'собира' : 601,
        u'жоп' : 602,
        u'снима' : 603,
        u'долг' : 604,
        u'жив' : 605,
        u'спокойн' : 606,
        u'просыпа' : 607,
        u'называ' : 608,
        u'бизнес' : 609,
        u'мысл' : 610,
        u'результат' : 611,
        u'сми' : 612,
        u'обеща' : 613,
        u'соб' : 614,
        u'пиш' : 615,
        u'поддержк' : 616,
        u'письм' : 617,
        u'цен' : 618,
        u'фот' : 619,
        u'леж' : 620,
        u'заболел' : 621,
        u'помощ' : 622,
        u'постоя' : 623,
        u'встреч' : 624,
        u'номер' : 625,
        u'молодец' : 626,
        u'референдум' : 627,
        u'глав' : 628,
        u'красн' : 629,
        u'ребенк' : 630,
        u'наверн' : 631,
        u'скаж' : 632,
        u'зла' : 633,
        u'заяв' : 634,
        u'ближайш' : 635,
        u'евген' : 636,
        u'пост' : 637,
        u'определен' : 638,
        u'межд' : 639,
        u'альб' : 640,
        u'петербург' : 641,
        u'район' : 642,
        u'питер' : 643,
        u'деньг' : 644,
        u'карт' : 645,
        u'жен' : 646,
        u'ник' : 647,
        u'кат' : 648,
        u'меда' : 649,
        u'фигн' : 650,
        u'слома' : 651,
        u'выбор' : 652,
        u'став' : 653,
        u'щас' : 654,
        u'могл' : 655,
        u'совершен' : 656,
        u'показыва' : 657,
        u'вперед' : 658,
        u'электричк' : 659,
        u'двер' : 660,
        u'волшебн' : 661,
        u'дал' : 662,
        u'дар' : 663,
        u'ад' : 664,
        u'ан' : 665,
        u'рассказа' : 666,
        u'бабушк' : 667,
        u'стол' : 668,
        u'зап' : 669,
        u'пораньш' : 670,
        u'провел' : 671,
        u'мат' : 672,
        u'шо' : 673,
        u'двух' : 674,
        u'количеств' : 675,
        u'мор' : 676,
        u'собак' : 677,
        u'клев' : 678,
        u'маленьк' : 679,
        u'вмк' : 680,
        u'оказа' : 681,
        u'бог' : 682,
        u'ног' : 683,
        u'мим' : 684,
        u'абсолютн' : 685,
        u'баб' : 686,
        u'повод' : 687,
        u'очеред' : 688,
        u'долж' : 689,
        u'явля' : 690,
        u'скучн' : 691,
        u'уста' : 692,
        u'секс' : 693,
        u'рассказыва' : 694,
        u'известн' : 695,
        u'н' : 696,
        u'женск' : 697,
        u'отвеча' : 698,
        u'умн' : 699,
        u'предлага' : 700,
        u'деревн' : 701,
        u'зуб' : 702,
        u'зат' : 703,
        u'врач' : 704,
        u'здан' : 705,
        u'реклам' : 706,
        u'проведен' : 707,
        u'премьер' : 708,
        u'предлож' : 709,
        u'митинг' : 710,
        u'призна' : 711,
        u'доктор' : 712,
        u'позит' : 713,
        u'личн' : 714,
        u'закон' : 715,
        u'холодн' : 716,
        u'спуст' : 717,
        u'дает' : 718,
        u'неб' : 719,
        u'парк' : 720,
        u'паралимпиад' : 721,
        u'прода' : 722,
        u'дерьм' : 723,
        u'причин' : 724,
        u'итог' : 725,
        u'гот' : 726,
        u'порадова' : 727,
        u'паспорт' : 728,
        u'обязательн' : 729,
        u'пишут' : 730,
        u'горж' : 731,
        u'горд' : 732,
        u'немн' : 733,
        u'пришел' : 734,
        u'тур' : 735,
        u'интерв' : 736,
        u'детск' : 737,
        u'потряса' : 738,
        u'спорт' : 739,
        u'поздн' : 740,
        u'обычн' : 741,
        u'проход' : 742,
        u'воен' : 743,
        u'млн' : 744,
        u'тяжел' : 745,
        u'штук' : 746,
        u'снят' : 747,
        u'придума' : 748,
        u'учен' : 749,
        u'вокруг' : 750,
        u'убива' : 751,
        u'сторон' : 752,
        u'тогд' : 753,
        u'лыжн' : 754,
        u'реша' : 755,
        u'конец' : 756,
        u'картинк' : 757,
        u'терпет' : 758,
        u'солнечн' : 759,
        u'уеха' : 760,
        u'могут' : 761,
        u'приложен' : 762,
        u'еха' : 763,
        u'шутк' : 764,
        u'легк' : 765,
        u'увидел' : 766,
        u'зал' : 767,
        u'трек' : 768,
        u'тоск' : 769,
        u'улыбк' : 770,
        u'мороз' : 771,
        u'выпуст' : 772,
        u'гуля' : 773,
        u'жела' : 774,
        u'мар' : 775,
        u'ел' : 776,
        u'назва' : 777,
        u'полност' : 778,
        u'гост' : 779,
        u'радостн' : 780,
        u'практическ' : 781,
        u'людьм' : 782,
        u'показа' : 783,
        u'короч' : 784,
        u'й' : 785,
        u'вест' : 786,
        u'ебан' : 787,
        u'км' : 788,
        u'разбира' : 789,
        u'огромн' : 790,
        u'служб' : 791,
        u'ситуац' : 792,
        u'числ' : 793,
        u'мнен' : 794,
        u'удовольств' : 795,
        u'международн' : 796,
        u'тип' : 797,
        u'выспа' : 798,
        u'х' : 799,
        u'выйдет' : 800,
        u'открыва' : 801,
        u'бред' : 802,
        u'стен' : 803,
        u'проверя' : 804,
        u'коф' : 805,
        u'вуз' : 806,
        u'умер' : 807,
        u'европ' : 808,
        u'недавн' : 809,
        u'пив' : 810,
        u'присоединен' : 811,
        u'слав' : 812,
        u'фраз' : 813,
        u'кафедр' : 814,
        u'бывш' : 815,
        u'эх' : 816,
        u'обсужда' : 817,
        u'отсутств' : 818,
        u'попрос' : 819,
        u'катан' : 820,
        u'рейтинг' : 821,
        u'вниман' : 822,
        u'вся' : 823,
        u'зоопарк' : 824,
        u'японск' : 825,
        u'планир' : 826,
        u'ясн' : 827,
        u'конференц' : 828,
        u'фестивал' : 829,
        u'удобн' : 830,
        u'нем' : 831,
        u'увол' : 832,
        u'губернатор' : 833,
        u'конфликт' : 834,
        u'ворот' : 835,
        u'станет' : 836,
        u'герман' : 837,
        u'диск' : 838,
        u'позор' : 839,
        u'свят' : 840,
        u'гол' : 841,
        u'кольц' : 842,
        u'идеальн' : 843,
        u'бляд' : 844,
        u'прочита' : 845,
        u'книжк' : 846,
        u'товарищ' : 847,
        u'поздравлен' : 848,
        u'фак' : 849,
        u'жертв' : 850,
        u'япон' : 851,
        u'знал' : 852,
        u'невыносим' : 853,
        u'знат' : 854,
        u'четверт' : 855,
        u'домик' : 856,
        u'помн' : 857,
        u'комнат' : 858,
        u'вывод' : 859,
        u'комп' : 860,
        u'снача' : 861,
        u'вышел' : 862,
        u'воздух' : 863,
        u'учеб' : 864,
        u'оценк' : 865,
        u'большинств' : 866,
        u'уб' : 867,
        u'уш' : 868,
        u'устро' : 869,
        u'средн' : 870,
        u'мобильн' : 871,
        u'состоян' : 872,
        u'безумн' : 873,
        u'наскольк' : 874,
        u'температур' : 875,
        u'информац' : 876,
        u'передач' : 877,
        u'ге' : 878,
        u'турнир' : 879,
        u'защит' : 880,
        u'родител' : 881,
        u'хрен' : 882,
        u'москвич' : 883,
        u'благодар' : 884,
        u'трех' : 885,
        u'др' : 886,
        u'весьм' : 887,
        u'улыба' : 888,
        u'маршрут' : 889,
        u'местн' : 890,
        u'пользовател' : 891,
        u'состо' : 892,
        u'чудесн' : 893,
        u'вход' : 894,
        u'баз' : 895,
        u'вол' : 896,
        u'север' : 897,
        u'возвраща' : 898,
        u'актер' : 899,
        u'жител' : 900,
        u'уда' : 901,
        u'доеха' : 902,
        u'род' : 903,
        u'ждал' : 904,
        u'сериа' : 905,
        u'случа' : 906,
        u'точн' : 907,
        u'тренировк' : 908,
        u'лож' : 909,
        u'спрашива' : 910,
        u'переход' : 911,
        u'автомобил' : 912,
        u'бож' : 913,
        u'молод' : 914,
        u'квартир' : 915,
        u'футболист' : 916,
        u'сад' : 917,
        u'гугл' : 918,
        u'прем' : 919,
        u'погибл' : 920,
        u'настоя' : 921,
        u'состав' : 922,
        u'отмен' : 923,
        u'национальн' : 924,
        u'обрат' : 925,
        u'существ' : 926,
        u'встреча' : 927,
        u'вышл' : 928,
        u'кошмар' : 929,
        u'ка' : 930,
        u'акц' : 931,
        u'дур' : 932,
        u'общаг' : 933,
        u'евр' : 934,
        u'топ' : 935,
        u'нуж' : 936,
        u'наук' : 937,
        u'победител' : 938,
        u'ошибк' : 939,
        u'травм' : 940,
        u'паден' : 941,
        u'депутат' : 942,
        u'полиц' : 943,
        u'политик' : 944,
        u'шест' : 945,
        u'меня' : 946,
        u'трансляц' : 947,
        u'разочарова' : 948,
        u'оон' : 949,
        u'водител' : 950,
        u'событ' : 951,
        u'продаж' : 952,
        u'соревнован' : 953,
        u'сутк' : 954,
        u'ахах' : 955,
        u'голуб' : 956,
        u'рекорд' : 957,
        u'драм' : 958,
        u'назнач' : 959,
        u'наход' : 960,
        u'хоккейн' : 961,
        u'леч' : 962,
        u'превраща' : 963,
        u'ог' : 964,
        u'спортсмен' : 965,
        u'проснул' : 966,
        u'трус' : 967,
        u'темн' : 968,
        u'рек' : 969,
        u'завоева' : 970,
        u'измен' : 971,
        u'способ' : 972,
        u'задолба' : 973,
        u'поговор' : 974,
        u'куд' : 975,
        u'выступа' : 976,
        u'больн' : 977,
        u'клип' : 978,
        u'кин' : 979,
        u'серг' : 980,
        u'урод' : 981,
        u'волн' : 982,
        u'найд' : 983,
        u'мерзк' : 984,
        u'полезн' : 985,
        u'сложн' : 986,
        u'запуст' : 987,
        u'свадьб' : 988,
        u'шок' : 989,
        u'чемпионат' : 990,
        u'связ' : 991,
        u'оборон' : 992,
        u'эстафет' : 993,
        u'одесс' : 994,
        u'отмет' : 995,
        u'стартап' : 996,
        u'произошл' : 997,
        u'развива' : 998,
        u'поеха' : 999,
        u'севастопол' : 1000,
        u'спал' : 1001,
        u'брос' : 1002,
        u'знач' : 1003,
        u'сравнен' : 1004,
        u'крупн' : 1005,
        u'россия' : 1006,
        u'дизайн' : 1007,
        u'валентин' : 1008,
        u'неожида' : 1009,
        u'огон' : 1010,
        u'пропуст' : 1011,
        u'математик' : 1012,
        u'мудак' : 1013,
        u'брав' : 1014,
        u'ладн' : 1015,
        u'тест' : 1016,
        u'рабоч' : 1017,
        u'провест' : 1018,
        u'хм' : 1019,
        u'одиночеств' : 1020,
        u'спортивн' : 1021,
        u'ходорковск' : 1022,
        u'фигурист' : 1023,
        u'великолепн' : 1024,
        u'душевн' : 1025,
        u'адрес' : 1026,
        u'наде' : 1027,
        u'пожар' : 1028,
        u'счет' : 1029,
        u'серебрян' : 1030,
        u'пес' : 1031,
        u'поиск' : 1032,
        u'пройдет' : 1033,
        u'живет' : 1034,
        u'хочеш' : 1035,
        u'нью' : 1036,
        u'помога' : 1037,
        u'лют' : 1038,
        u'пада' : 1039,
        u'посмотрет' : 1040,
        u'подарок' : 1041,
        u'преподавател' : 1042,
        u'слез' : 1043,
        u'ролик' : 1044,
        u'обам' : 1045,
        u'посвящен' : 1046,
        u'ах' : 1047,
        u'посмотр' : 1048,
        u'планет' : 1049,
        u'задержа' : 1050,
        u'паук' : 1051,
        u'вк' : 1052,
        u'уныл' : 1053,
        u'спектакл' : 1054,
        u'уютн' : 1055,
        u'андр' : 1056,
        u'качеств' : 1057,
        u'ес' : 1058,
        u'паршив' : 1059,
        u'пробк' : 1060,
        u'действ' : 1061,
        u'нах' : 1062,
        u'кем' : 1063,
        u'рол' : 1064,
        u'предсто' : 1065,
        u'взгляд' : 1066,
        u'площад' : 1067,
        u'влюблен' : 1068,
        u'либ' : 1069,
        u'форм' : 1070,
        u'фонд' : 1071,
        u'дальш' : 1072,
        u'дальн' : 1073,
        u'основ' : 1074,
        u'внезапн' : 1075,
        u'сестр' : 1076,
        u'че' : 1077,
        u'чо' : 1078,
        u'навсегд' : 1079,
        u'вкусн' : 1080,
        u'дмитр' : 1081,
        u'подня' : 1082,
        u'американц' : 1083,
        u'плат' : 1084,
        u'уважа' : 1085,
        u'разговор' : 1086,
        u'дипл' : 1087,
        u'виж' : 1088,
        u'режим' : 1089,
        u'советск' : 1090,
        u'подруг' : 1091,
        u'мужск' : 1092,
        u'старт' : 1093,
        u'макс' : 1094,
        u'скуча' : 1095,
        u'шорт' : 1096,
        u'пожалуйст' : 1097,
        u'сообщ' : 1098,
        u'систем' : 1099,
        u'хакер' : 1100,
        u'полицейск' : 1101,
        u'успел' : 1102,
        u'восток' : 1103,
        u'сосед' : 1104,
        u'сообщен' : 1105,
        u'чист' : 1106,
        u'придет' : 1107,
        u'сих' : 1108,
        u'науч' : 1109,
        u'телевизор' : 1110,
        u'отмеча' : 1111,
        u'езд' : 1112,
        u'слух' : 1113,
        u'миров' : 1114,
        u'искрен' : 1115,
        u'учебн' : 1116,
        u'телек' : 1117,
        u'актрис' : 1118,
        u'сон' : 1119,
        u'станц' : 1120,
        u'спор' : 1121,
        u'съемк' : 1122,
        u'карьер' : 1123,
        u'мальчик' : 1124,
        u'особ' : 1125,
        u'вечн' : 1126,
        u'заявлен' : 1127,
        u'каток' : 1128,
        u'иска' : 1129,
        u'горяч' : 1130,
        u'увид' : 1131,
        u'имет' : 1132,
        u'заход' : 1133,
        u'слыша' : 1134,
        u'вспомн' : 1135,
        u'войск' : 1136,
        u'выступлен' : 1137,
        u'разда' : 1138,
        u'паралимпийск' : 1139,
        u'танк' : 1140,
        u'предложен' : 1141,
        u'буха' : 1142,
        u'попробова' : 1143,
        u'медлен' : 1144,
        u'прежд' : 1145,
        u'кров' : 1146,
        u'выда' : 1147,
        u'конкурс' : 1148,
        u'сотрудник' : 1149,
        u'факел' : 1150,
        u'эфир' : 1151,
        u'чест' : 1152,
        u'тума' : 1153,
        u'цвет' : 1154,
        u'обложк' : 1155,
        u'разн' : 1156,
        u'экран' : 1157,
        u'семестр' : 1158,
        u'реб' : 1159,
        u'винд' : 1160,
        u'век' : 1161,
        u'культур' : 1162,
        u'территор' : 1163,
        u'препод' : 1164,
        u'восторг' : 1165,
        u'кит' : 1166,
        u'предмет' : 1167,
        u'сладост' : 1168,
        u'отделен' : 1169,
        u'приключен' : 1170,
        u'парт' : 1171,
        u'бля' : 1172,
        u'отда' : 1173,
        u'откровен' : 1174,
        u'английск' : 1175,
        u'стадион' : 1176,
        u'окончательн' : 1177,
        u'мэр' : 1178,
        u'юмор' : 1179,
        u'г' : 1180,
        u'истин' : 1181,
        u'сплошн' : 1182,
        u'тел' : 1183,
        u'корпус' : 1184,
        u'организм' : 1185,
        u'капец' : 1186,
        u'самолет' : 1187,
        u'миллиард' : 1188,
        u'борот' : 1189,
        u'протест' : 1190,
        u'заня' : 1191,
        u'почита' : 1192,
        u'офис' : 1193,
        u'эмоц' : 1194,
        u'продукт' : 1195,
        u'компьютер' : 1196,
        u'мер' : 1197,
        u'обновлен' : 1198,
        u'разреш' : 1199,
        u'набира' : 1200,
        u'прак' : 1201,
        u'появлен' : 1202,
        u'бассейн' : 1203,
        u'сел' : 1204,
        u'одноклассник' : 1205,
        u'труд' : 1206,
        u'ждет' : 1207,
        u'дот' : 1208,
        u'матер' : 1209,
        u'пообща' : 1210,
        u'классик' : 1211,
        u'внутр' : 1212,
        u'начальник' : 1213,
        u'обществ' : 1214,
        u'заказ' : 1215,
        u'послуша' : 1216,
        u'взрыв' : 1217,
        u'вылож' : 1218,
        u'такс' : 1219,
        u'кайф' : 1220,
        u'ул' : 1221,
        u'твор' : 1222,
        u'смогл' : 1223,
        u'социальн' : 1224,
        u'прос' : 1225,
        u'алекс' : 1226,
        u'рома' : 1227,
        u'плака' : 1228,
        u'сух' : 1229,
        u'документ' : 1230,
        u'землетрясен' : 1231,
        u'включа' : 1232,
        u'уровн' : 1233,
        u'сфер' : 1234,
        u'школьник' : 1235,
        u'сотн' : 1236,
        u'болел' : 1237,
        u'театр' : 1238,
        u'январ' : 1239,
        u'удал' : 1240,
        u'удач' : 1241,
        u'дво' : 1242,
        u'жалк' : 1243,
        u'биткоин' : 1244,
        u'раздража' : 1245,
        u'приб' : 1246,
        u'свеж' : 1247,
        u'лидер' : 1248,
        u'тв' : 1249,
        u'плюс' : 1250,
        u'невозможн' : 1251,
        u'возраст' : 1252,
        u'сист' : 1253,
        u'непониман' : 1254,
        u'действительн' : 1255,
        u'уезжа' : 1256,
        u'канад' : 1257,
        u'обучен' : 1258,
        u'сожален' : 1259,
        u'аа' : 1260,
        u'мда' : 1261,
        u'представля' : 1262,
        u'школьн' : 1263,
        u'янукович' : 1264,
        u'исполня' : 1265,
        u'посет' : 1266,
        u'увидет' : 1267,
        u'арм' : 1268,
        u'атмосферн' : 1269,
        u'треб' : 1270,
        u'мисс' : 1271,
        u'возьм' : 1272,
        u'википед' : 1273,
        u'сдава' : 1274,
        u'отправ' : 1275,
        u'стро' : 1276,
        u'избра' : 1277,
        u'ви' : 1278,
        u'университет' : 1279,
        u'ольг' : 1280,
        u'задан' : 1281,
        u'уход' : 1282,
        u'крова' : 1283,
        u'провер' : 1284,
        u'воврем' : 1285,
        u'балет' : 1286,
        u'бан' : 1287,
        u'сын' : 1288,
        u'похмел' : 1289,
        u'презентац' : 1290,
        u'доступ' : 1291,
        u'забавн' : 1292,
        u'уеба' : 1293,
        u'шли' : 1294,
        u'иностра' : 1295,
        u'йорк' : 1296,
        u'заеба' : 1297,
        u'атмосфер' : 1298,
        u'нарисова' : 1299,
        u'западн' : 1300,
        u'жест' : 1301,
        u'дебильн' : 1302,
        u'виде' : 1303,
        u'зон' : 1304,
        u'секунд' : 1305,
        u'расстро' : 1306,
        u'замет' : 1307,
        u'идут' : 1308,
        u'уйт' : 1309,
        u'подготовк' : 1310,
        u'чувак' : 1311,
        u'медвед' : 1312,
        u'управлен' : 1313,
        u'ген' : 1314,
        u'сказк' : 1315,
        u'лондон' : 1316,
        u'извин' : 1317,
        u'такж' : 1318,
        u'собствен' : 1319,
        u'кубк' : 1320,
        u'памят' : 1321,
        u'польз' : 1322,
        u'мин' : 1323,
        u'основн' : 1324,
        u'донецк' : 1325,
        u'шерлок' : 1326,
        u'любв' : 1327,
        u'невролог' : 1328,
        u'образ' : 1329,
        u'упа' : 1330,
        u'добав' : 1331,
        u'живут' : 1332,
        u'вдруг' : 1333,
        u'покупк' : 1334,
        u'включ' : 1335,
        u'вторник' : 1336,
        u'слыш' : 1337,
        u'мелк' : 1338,
        u'независим' : 1339,
        u'сервис' : 1340,
        u'зада' : 1341,
        u'расписан' : 1342,
        u'вполн' : 1343,
        u'неловк' : 1344,
        u'ток' : 1345,
        u'встава' : 1346,
        u'мастер' : 1347,
        u'волос' : 1348,
        u'чуж' : 1349,
        u'фигурн' : 1350,
        u'популярн' : 1351,
        u'гряз' : 1352,
        u'нашел' : 1353,
        u'серьезн' : 1354,
        u'девушек' : 1355,
        u'судьб' : 1356,
        u'мозг' : 1357,
        u'челябинск' : 1358,
        u'сентябр' : 1359,
        u'комплект' : 1360,
        u'поднима' : 1361,
        u'госдум' : 1362,
        u'трат' : 1363,
        u'поед' : 1364,
        u'физическ' : 1365,
        u'будьт' : 1366,
        u'соскуч' : 1367,
        u'куртк' : 1368,
        u'обязан' : 1369,
        u'безопасн' : 1370,
        u'поката' : 1371,
        u'автомат' : 1372,
        u'код' : 1373,
        u'кол' : 1374,
        u'мягк' : 1375,
        u'иск' : 1376,
        u'авар' : 1377,
        u'ора' : 1378,
        u'интерес' : 1379,
        u'уснут' : 1380,
        u'внутрен' : 1381,
        u'производств' : 1382,
        u'егэ' : 1383,
        u'согласн' : 1384,
        u'останов' : 1385,
        u'обошл' : 1386,
        u'поразительн' : 1387,
        u'должност' : 1388,
        u'уголовн' : 1389,
        u'опубликова' : 1390,
        u'вызыва' : 1391,
        u'кружевн' : 1392,
        u'противн' : 1393,
        u'инстагр' : 1394,
        u'модел' : 1395,
        u'ярославл' : 1396,
        u'теор' : 1397,
        u'погуля' : 1398,
        u'греба' : 1399,
        u'ох' : 1400,
        u'объяв' : 1401,
        u'сибир' : 1402,
        u'поменя' : 1403,
        u'посуд' : 1404,
        u'чертов' : 1405,
        u'фина' : 1406,
        u'дают' : 1407,
        u'пальц' : 1408,
        u'показ' : 1409,
        u'павел' : 1410,
        u'мег' : 1411,
        u'вилухин' : 1412,
        u'сектор' : 1413,
        u'досмотрел' : 1414,
        u'великобритан' : 1415,
        u'прогресс' : 1416,
        u'требова' : 1417,
        u'держа' : 1418,
        u'посвяща' : 1419,
        u'нарушен' : 1420,
        u'индекс' : 1421,
        u'воробьев' : 1422,
        u'рашк' : 1423,
        u'ребенок' : 1424,
        u'одинок' : 1425,
        u'стандарт' : 1426,
        u'кур' : 1427,
        u'иде' : 1428,
        u'словн' : 1429,
        u'немецк' : 1430,
        u'комментатор' : 1431,
        u'льет' : 1432,
        u'венесуэл' : 1433,
        u'сгму' : 1434,
        u'доступн' : 1435,
        u'студ' : 1436,
        u'малыш' : 1437,
        u'поддержива' : 1438,
        u'мамочк' : 1439,
        u'бренд' : 1440,
        u'разработк' : 1441,
        u'комиссаров' : 1442,
        u'выплат' : 1443,
        u'размещен' : 1444,
        u'классическ' : 1445,
        u'геро' : 1446,
        u'убежда' : 1447,
        u'появля' : 1448,
        u'херов' : 1449,
        u'идиотизм' : 1450,
        u'зло' : 1451,
        u'граф' : 1452,
        u'настольк' : 1453,
        u'кошк' : 1454,
        u'переста' : 1455,
        u'выш' : 1456,
        u'бутылк' : 1457,
        u'вкус' : 1458,
        u'учебник' : 1459,
        u'коллекц' : 1460,
        u'круг' : 1461,
        u'мю' : 1462,
        u'телекана' : 1463,
        u'отказыва' : 1464,
        u'участник' : 1465,
        u'линз' : 1466,
        u'россиясш' : 1467,
        u'зрител' : 1468,
        u'журна' : 1469,
        u'выкуп' : 1470,
        u'нереальн' : 1471,
        u'откуд' : 1472,
        u'вчерашн' : 1473,
        u'приличн' : 1474,
        u'столов' : 1475,
        u'неплох' : 1476,
        u'новогодн' : 1477,
        u'опасн' : 1478,
        u'взросл' : 1479,
        u'осен' : 1480,
        u'немц' : 1481,
        u'влюбл' : 1482,
        u'футболк' : 1483,
        u'впечатлен' : 1484,
        u'коньк' : 1485,
        u'регулярн' : 1486,
        u'кризис' : 1487,
        u'берлин' : 1488,
        u'убед' : 1489,
        u'инженер' : 1490,
        u'отел' : 1491,
        u'возл' : 1492,
        u'фамил' : 1493,
        u'режиссер' : 1494,
        u'богат' : 1495,
        u'аккаунт' : 1496,
        u'четверг' : 1497,
        u'явн' : 1498,
        u'вайфа' : 1499,
        u'понят' : 1500,
        u'толк' : 1501,
        u'ждеш' : 1502,
        u'будильник' : 1503,
        u'весен' : 1504,
        u'стрем' : 1505,
        u'переговор' : 1506,
        u'виктор' : 1507,
        u'исполнен' : 1508,
        u'меша' : 1509,
        u'ра' : 1510,
        u'блеа' : 1511,
        u'привыка' : 1512,
        u'конкретн' : 1513,
        u'предыдущ' : 1514,
        u'ожидан' : 1515,
        u'ссылк' : 1516,
        u'п' : 1517,
        u'звезд' : 1518,
        u'знают' : 1519,
        u'верн' : 1520,
        u'л' : 1521,
        u'восьм' : 1522,
        u'худш' : 1523,
        u'начал' : 1524,
        u'сыгра' : 1525,
        u'обща' : 1526,
        u'одинаков' : 1527,
        u'упорн' : 1528,
        u'украинц' : 1529,
        u'доход' : 1530,
        u'светл' : 1531,
        u'херн' : 1532,
        u'ху' : 1533,
        u'продолж' : 1534,
        u'современ' : 1535,
        u'комментар' : 1536,
        u'подписа' : 1537,
        u'увер' : 1538,
        u'расскаж' : 1539,
        u'ката' : 1540,
        u'заверш' : 1541,
        u'библиотек' : 1542,
        u'проигра' : 1543,
        u'дацюк' : 1544,
        u'кида' : 1545,
        u'отставк' : 1546,
        u'пожела' : 1547,
        u'стих' : 1548,
        u'прийт' : 1549,
        u'париж' : 1550,
        u'д' : 1551,
        u'побыва' : 1552,
        u'опуска' : 1553,
        u'остальн' : 1554,
        u'банковск' : 1555,
        u'академ' : 1556,
        u'черноморск' : 1557,
        u'август' : 1558,
        u'пода' : 1559,
        u'дат' : 1560,
        u'домашн' : 1561,
        u'та' : 1562,
        u'франц' : 1563,
        u'шаг' : 1564,
        u'списк' : 1565,
        u'этаж' : 1566,
        u'минус' : 1567,
        u'встал' : 1568,
        u'комплимент' : 1569,
        u'знакомств' : 1570,
        u'гуманитарн' : 1571,
        u'гад' : 1572,
        u'канал' : 1573,
        u'поспа' : 1574,
        u'понадоб' : 1575,
        u'автор' : 1576,
        u'далек' : 1577,
        u'политическ' : 1578,
        u'бо' : 1579,
        u'ал' : 1580,
        u'угнета' : 1581,
        u'заработа' : 1582,
        u'пользова' : 1583,
        u'солдат' : 1584,
        u'ангел' : 1585,
        u'стоя' : 1586,
        u'контрольн' : 1587,
        u'горьк' : 1588,
        u'зерка' : 1589,
        u'очк' : 1590,
        u'газет' : 1591,
        u'совещан' : 1592,
        u'сест' : 1593,
        u'болезн' : 1594,
        u'выпуск' : 1595,
        u'борьб' : 1596,
        u'сидел' : 1597,
        u'кнопк' : 1598,
        u'жар' : 1599,
        u'исправ' : 1600,
        u'прекрат' : 1601,
        u'использова' : 1602,
        u'охот' : 1603,
        u'разбит' : 1604,
        u'пробл' : 1605,
        u'призва' : 1606,
        u'участ' : 1607,
        u'выйт' : 1608,
        u'необходим' : 1609,
        u'заказа' : 1610,
        u'жираф' : 1611,
        u'мол' : 1612,
        u'отозва' : 1613,
        u'удивительн' : 1614,
        u'лин' : 1615,
        u'прелестн' : 1616,
        u'крас' : 1617,
        u'медведев' : 1618,
        u'точк' : 1619,
        u'букв' : 1620,
        u'практик' : 1621,
        u'разобра' : 1622,
        u'просмотр' : 1623,
        u'ремонт' : 1624,
        u'хренов' : 1625,
        u'чм' : 1626,
        u'дружб' : 1627,
        u'коллег' : 1628,
        u'прогулк' : 1629,
        u'читател' : 1630,
        u'пойт' : 1631,
        u'длин' : 1632,
        u'навальн' : 1633,
        u'ин' : 1634,
        u'апрел' : 1635,
        u'балл' : 1636,
        u'ищ' : 1637,
        u'норвег' : 1638,
        u'водк' : 1639,
        u'вор' : 1640,
        u'деся' : 1641,
        u'привел' : 1642,
        u'природ' : 1643,
        u'наблюда' : 1644,
        u'саш' : 1645,
        u'поздрав' : 1646,
        u'гаджет' : 1647,
        u'антон' : 1648,
        u'погибш' : 1649,
        u'тащ' : 1650,
        u'бега' : 1651,
        u'экзамен' : 1652,
        u'процессор' : 1653,
        u'шлюх' : 1654,
        u'смерт' : 1655,
        u'зрелищн' : 1656,
        u'непонятн' : 1657,
        u'творчеств' : 1658,
        u'удивля' : 1659,
        u'залипа' : 1660,
        u'тви' : 1661,
        u'страда' : 1662,
        u'зелен' : 1663,
        u'выступ' : 1664,
        u'картин' : 1665,
        u'жил' : 1666,
        u'понятн' : 1667,
        u'покупа' : 1668,
        u'вагон' : 1669,
        u'инач' : 1670,
        u'например' : 1671,
        u'суров' : 1672,
        u'продолжен' : 1673,
        u'маш' : 1674,
        u'разработчик' : 1675,
        u'наушник' : 1676,
        u'резолюц' : 1677,
        u'бьорндал' : 1678,
        u'жарк' : 1679,
        u'постро' : 1680,
        u'гордост' : 1681,
        u'бота' : 1682,
        u'карточн' : 1683,
        u'сладк' : 1684,
        u'мост' : 1685,
        u'случайн' : 1686,
        u'деканат' : 1687,
        u'заблокирова' : 1688,
        u'памя' : 1689,
        u'обществен' : 1690,
        u'добавля' : 1691,
        u'гадк' : 1692,
        u'маршрутк' : 1693,
        u'сир' : 1694,
        u'син' : 1695,
        u'облак' : 1696,
        u'депресс' : 1697,
        u'справ' : 1698,
        u'забра' : 1699,
        u'подвел' : 1700,
        u'сме' : 1701,
        u'груз' : 1702,
        u'гражданск' : 1703,
        u'голодн' : 1704,
        u'подтверд' : 1705,
        u'адск' : 1706,
        u'администрац' : 1707,
        u'ютуб' : 1708,
        u'обвиня' : 1709,
        u'пространств' : 1710,
        u'лежа' : 1711,
        u'теря' : 1712,
        u'повторя' : 1713,
        u'мизулин' : 1714,
        u'рассужда' : 1715,
        u'олег' : 1716,
        u'поет' : 1717,
        u'осознава' : 1718,
        u'остров' : 1719,
        u'скрыва' : 1720,
        u'назначен' : 1721,
        u'дорожк' : 1722,
        u'прозрачн' : 1723,
        u'порядок' : 1724,
        u'камер' : 1725,
        u'представител' : 1726,
        u'укра' : 1727,
        u'операц' : 1728,
        u'жрат' : 1729,
        u'юр' : 1730,
        u'юл' : 1731,
        u'можеш' : 1732,
        u'сдан' : 1733,
        u'планшет' : 1734,
        u'коп' : 1735,
        u'естествен' : 1736,
        u'финлянд' : 1737,
        u'жутк' : 1738,
        u'наткнул' : 1739,
        u'сохран' : 1740,
        u'полумарафон' : 1741,
        u'имел' : 1742,
        u'бесконечн' : 1743,
        u'гражда' : 1744,
        u'прилета' : 1745,
        u'охренительн' : 1746,
        u'катюш' : 1747,
        u'возглав' : 1748,
        u'высыпа' : 1749,
        u'сердц' : 1750,
        u'мультик' : 1751,
        u'ошиба' : 1752,
        u'японц' : 1753,
        u'велосипед' : 1754,
        u'лаборатор' : 1755,
        u'пит' : 1756,
        u'робот' : 1757,
        u'одиночн' : 1758,
        u'вертолет' : 1759,
        u'мечта' : 1760,
        u'пропада' : 1761,
        u'напиш' : 1762,
        u'цензур' : 1763,
        u'прежн' : 1764,
        u'сигарет' : 1765,
        u'направ' : 1766,
        u'защища' : 1767,
        u'мраз' : 1768,
        u'хо' : 1769,
        u'колон' : 1770,
        u'мчс' : 1771,
        u'инвестицион' : 1772,
        u'политот' : 1773,
        u'помоч' : 1774,
        u'обнаруж' : 1775,
        u'забива' : 1776,
        u'помог' : 1777,
        u'хож' : 1778,
        u'ом' : 1779,
        u'оо' : 1780,
        u'оп' : 1781,
        u'зарубежн' : 1782,
        u'месячн' : 1783,
        u'размер' : 1784,
        u'оч' : 1785,
        u'рейс' : 1786,
        u'грушевск' : 1787,
        u'разв' : 1788,
        u'приравня' : 1789,
        u'министерств' : 1790,
        u'развлекательн' : 1791,
        u'божествен' : 1792,
        u'содержан' : 1793,
        u'реж' : 1794,
        u'разрешен' : 1795,
        u'исключительн' : 1796,
        u'лета' : 1797,
        u'халк' : 1798,
        u'еба' : 1799,
        u'забыва' : 1800,
        u'лыжник' : 1801,
        u'пьян' : 1802,
        u'негат' : 1803,
        u'набор' : 1804,
        u'приступ' : 1805,
        u'веб' : 1806,
        u'сохраня' : 1807,
        u'пе' : 1808,
        u'моментальн' : 1809,
        u'па' : 1810,
        u'государствен' : 1811,
        u'аэропорт' : 1812,
        u'ссср' : 1813,
        u'исполн' : 1814,
        u'отправлен' : 1815,
        u'рост' : 1816,
        u'бен' : 1817,
        u'наград' : 1818,
        u'бет' : 1819,
        u'захват' : 1820,
        u'познер' : 1821,
        u'посольств' : 1822,
        u'инвестор' : 1823,
        u'оборот' : 1824,
        u'восьмерк' : 1825,
        u'одержа' : 1826,
        u'услов' : 1827,
        u'неч' : 1828,
        u'испорт' : 1829,
        u'вызва' : 1830,
        u'уничтож' : 1831,
        u'оформ' : 1832,
        u'организова' : 1833,
        u'трамплин' : 1834,
        u'лист' : 1835,
        u'собянин' : 1836,
        u'челс' : 1837,
        u'аллерг' : 1838,
        u'гроз' : 1839,
        u'технолог' : 1840,
        u'репертуар' : 1841,
        u'пал' : 1842,
        u'ля' : 1843,
        u'дневн' : 1844,
        u'забег' : 1845,
        u'хран' : 1846,
        u'волк' : 1847,
        u'умира' : 1848,
        u'националист' : 1849,
        u'лома' : 1850,
        u'специалист' : 1851,
        u'максимальн' : 1852,
        u'перееха' : 1853,
        u'приезжа' : 1854,
        u'возьмет' : 1855,
        u'швец' : 1856,
        u'принесл' : 1857,
        u'пыл' : 1858,
        u'гагарин' : 1859,
        u'татьянин' : 1860,
        u'мудрост' : 1861,
        u'обраща' : 1862,
        u'квн' : 1863,
        u'еврейск' : 1864,
        u'поведен' : 1865,
        u'нижн' : 1866,
        u'установ' : 1867,
        u'аргумент' : 1868,
        u'сумк' : 1869,
        u'ма' : 1870,
        u'заброс' : 1871,
        u'относ' : 1872,
        u'красавец' : 1873,
        u'гос' : 1874,
        u'скотин' : 1875,
        u'призер' : 1876,
        u'мишк' : 1877,
        u'швейцар' : 1878,
        u'заметн' : 1879,
        u'америк' : 1880,
        u'цикл' : 1881,
        u'алкогол' : 1882,
        u'вирус' : 1883,
        u'столиц' : 1884,
        u'продуктивн' : 1885,
        u'калифорн' : 1886,
        u'исход' : 1887,
        u'курсов' : 1888,
        u'дочита' : 1889,
        u'пишет' : 1890,
        u'готовл' : 1891,
        u'парочк' : 1892,
        u'подошел' : 1893,
        u'озер' : 1894,
        u'коньяк' : 1895,
        u'спонта' : 1896,
        u'уязвим' : 1897,
        u'мистер' : 1898,
        u'розов' : 1899,
        u'проверк' : 1900,
        u'уровен' : 1901,
        u'заседан' : 1902,
        u'подума' : 1903,
        u'философ' : 1904,
        u'идиот' : 1905,
        u'блондинк' : 1906,
        u'скелетон' : 1907,
        u'вернет' : 1908,
        u'простот' : 1909,
        u'несмотр' : 1910,
        u'держ' : 1911,
        u'жюр' : 1912,
        u'безысходн' : 1913,
        u'отказа' : 1914,
        u'ответствен' : 1915,
        u'захотел' : 1916,
        u'каф' : 1917,
        u'доставля' : 1918,
        u'чувствова' : 1919,
        u'покажут' : 1920,
        u'проспа' : 1921,
        u'красноярск' : 1922,
        u'тус' : 1923,
        u'ю' : 1924,
        u'прова' : 1925,
        u'туд' : 1926,
        u'хам' : 1927,
        u'проща' : 1928,
        u'происход' : 1929,
        u'знак' : 1930,
        u'киевск' : 1931,
        u'спас' : 1932,
        u'снежинк' : 1933,
        u'дим' : 1934,
        u'охуен' : 1935,
        u'спортсм' : 1936,
        u'респект' : 1937,
        u'рынок' : 1938,
        u'намерен' : 1939,
        u'разыгра' : 1940,
        u'егор' : 1941,
        u'удивл' : 1942,
        u'водник' : 1943,
        u'успоко' : 1944,
        u'з' : 1945,
        u'доч' : 1946,
        u'академик' : 1947,
        u'принес' : 1948,
        u'автоматическ' : 1949,
        u'сдает' : 1950,
        u'ру' : 1951,
        u'ри' : 1952,
        u'учительниц' : 1953,
        u'сервер' : 1954,
        u'корабл' : 1955,
        u'пуховик' : 1956,
        u'отечеств' : 1957,
        u'повтор' : 1958,
        u'поражен' : 1959,
        u'пошел' : 1960,
        u'медик' : 1961,
        u'рубеж' : 1962,
        u'повезл' : 1963,
        u'фу' : 1964,
        u'сочинск' : 1965,
        u'ленинградск' : 1966,
        u'диалог' : 1967,
        u'кита' : 1968,
        u'символ' : 1969,
        u'бесполезн' : 1970,
        u'стокгольм' : 1971,
        u'праздн' : 1972,
        u'скача' : 1973,
        u'курск' : 1974,
        u'кусок' : 1975,
        u'шоколад' : 1976,
        u'мокр' : 1977,
        u'поход' : 1978,
        u'неужел' : 1979,
        u'атлетик' : 1980,
        u'проб' : 1981,
        u'колес' : 1982,
        u'холодильник' : 1983,
        u'кругл' : 1984,
        u'факультет' : 1985,
        u'стан' : 1986,
        u'курсач' : 1987,
        u'несправедлив' : 1988,
        u'дурацк' : 1989,
        u'высок' : 1990,
        u'рекламн' : 1991,
        u'ящик' : 1992,
        u'декабр' : 1993,
        u'бронзов' : 1994,
        u'робокоп' : 1995,
        u'судебн' : 1996,
        u'браузер' : 1997,
        u'текст' : 1998,
        u'повест' : 1999,
        u'звук' : 2000,
        u'ха' : 2001,
        u'сут' : 2002,
        u'спаса' : 2003,
        u'дополнен' : 2004,
        u'педиатр' : 2005,
        u'отечествен' : 2006,
        u'трогательн' : 2007,
        u'принят' : 2008,
        u'гигантск' : 2009,
        u'гадост' : 2010,
        u'итак' : 2011,
        u'коротк' : 2012,
        u'коррупц' : 2013,
        u'пахнет' : 2014,
        u'стыдн' : 2015,
        u'федерац' : 2016,
        u'болгарск' : 2017,
        u'застав' : 2018,
        u'смартфон' : 2019,
        u'релиз' : 2020,
        u'цветн' : 2021,
        u'запад' : 2022,
        u'сб' : 2023,
        u'ск' : 2024,
        u'зачетк' : 2025,
        u'оскар' : 2026,
        u'порт' : 2027,
        u'вспомина' : 2028,
        u'пример' : 2029,
        u'гп' : 2030,
        u'гз' : 2031,
        u'поддерж' : 2032,
        u'отключен' : 2033,
        u'командн' : 2034,
        u'разговарива' : 2035,
        u'волонтер' : 2036,
        u'малышк' : 2037,
        u'ноут' : 2038,
        u'удар' : 2039,
        u'пропа' : 2040,
        u'гребан' : 2041,
        u'принос' : 2042,
        u'зайцев' : 2043,
        u'лаб' : 2044,
        u'дисциплин' : 2045,
        u'приз' : 2046,
        u'ласков' : 2047,
        u'вечеринк' : 2048,
        u'кибернетик' : 2049,
        u'профессиональн' : 2050,
        u'лишн' : 2051,
        u'неприятн' : 2052,
        u'общен' : 2053,
        u'пройт' : 2054,
        u'миха' : 2055,
        u'сверл' : 2056,
        u'ч' : 2057,
        u'профил' : 2058,
        u'художествен' : 2059,
        u'деятельн' : 2060,
        u'шипулин' : 2061,
        u'чащ' : 2062,
        u'дерьмов' : 2063,
        u'фотик' : 2064,
        u'мюзикл' : 2065,
        u'глупост' : 2066,
        u'неудачник' : 2067,
        u'ледов' : 2068,
        u'завтрашн' : 2069,
        u'экономик' : 2070,
        u'благодарн' : 2071,
        u'запис' : 2072,
        u'расстоян' : 2073,
        u'потер' : 2074,
        u'позитивн' : 2075,
        u'бессмертн' : 2076,
        u'пздц' : 2077,
        u'хоккеист' : 2078,
        u'выпа' : 2079,
        u'организац' : 2080,
        u'бл' : 2081,
        u'шапк' : 2082,
        u'перм' : 2083,
        u'фолловер' : 2084,
        u'аж' : 2085,
        u'аз' : 2086,
        u'ставк' : 2087,
        u'ар' : 2088,
        u'мегафон' : 2089,
        u'съезд' : 2090,
        u'полуфина' : 2091,
        u'сфотка' : 2092,
        u'даш' : 2093,
        u'вылетел' : 2094,
        u'воевод' : 2095,
        u'оцен' : 2096,
        u'телеканал' : 2097,
        u'кофейн' : 2098,
        u'легч' : 2099,
        u'трем' : 2100,
        u'ущербн' : 2101,
        u'потрясающ' : 2102,
        u'игор' : 2103,
        u'григор' : 2104,
        u'научн' : 2105,
        u'чиновник' : 2106,
        u'ясност' : 2107,
        u'кончен' : 2108,
        u'питерск' : 2109,
        u'болотн' : 2110,
        u'исправля' : 2111,
        u'подел' : 2112,
        u'тортик' : 2113,
        u'ва' : 2114,
        u'мвд' : 2115,
        u'оператор' : 2116,
        u'вс' : 2117,
        u'сран' : 2118,
        u'ужин' : 2119,
        u'подготов' : 2120,
        u'подслуша' : 2121,
        u'позвон' : 2122,
        u'танц' : 2123,
        u'максимум' : 2124,
        u'признак' : 2125,
        u'фотка' : 2126,
        u'бах' : 2127,
        u'англ' : 2128,
        u'четк' : 2129,
        u'однажд' : 2130,
        u'родственник' : 2131,
        u'горазд' : 2132,
        u'мак' : 2133,
        u'выросл' : 2134,
        u'введ' : 2135,
        u'блогер' : 2136,
        u'активист' : 2137,
        u'садик' : 2138,
        u'цеп' : 2139,
        u'знаеш' : 2140,
        u'ше' : 2141,
        u'умничк' : 2142,
        u'пью' : 2143,
        u'симулятор' : 2144,
        u'свирск' : 2145,
        u'бумажн' : 2146,
        u'факт' : 2147,
        u'наркотик' : 2148,
        u'ушел' : 2149,
        u'биатлонист' : 2150,
        u'художник' : 2151,
        u'рос' : 2152,
        u'тлен' : 2153,
        u'рок' : 2154,
        u'рож' : 2155,
        u'зря' : 2156,
        u'подпис' : 2157,
        u'привыкнут' : 2158,
        u'маск' : 2159,
        u'легитимн' : 2160,
        u'срочн' : 2161,
        u'масс' : 2162,
        u'объяснен' : 2163,
        u'учител' : 2164,
        u'жестк' : 2165,
        u'мок' : 2166,
        u'гостиниц' : 2167,
        u'ключ' : 2168,
        u'руководств' : 2169,
        u'жирн' : 2170,
        u'близ' : 2171,
        u'андре' : 2172,
        u'отпуск' : 2173,
        u'лиг' : 2174,
        u'поют' : 2175,
        u'кретин' : 2176,
        u'кра' : 2177,
        u'отд' : 2178,
        u'братск' : 2179,
        u'запомн' : 2180,
        u'шоколадк' : 2181,
        u'флаг' : 2182,
        u'границ' : 2183,
        u'подсветк' : 2184,
        u'заслужен' : 2185,
        u'прошедш' : 2186,
        u'видн' : 2187,
        u'дяд' : 2188,
        u'замен' : 2189,
        u'создава' : 2190,
        u'семинар' : 2191,
        u'слегк' : 2192,
        u'россиян' : 2193,
        u'фристайлистк' : 2194,
        u'шоппинг' : 2195,
        u'редк' : 2196,
        u'дружн' : 2197,
        u'юрист' : 2198,
        u'республик' : 2199,
        u'стоимост' : 2200,
        u'принима' : 2201,
        u'передума' : 2202,
        u'переда' : 2203,
        u'мощн' : 2204,
        u'купл' : 2205,
        u'поликлиник' : 2206,
        u'лох' : 2207,
        u'охра' : 2208,
        u'плюсов' : 2209,
        u'освобод' : 2210,
        u'вредн' : 2211,
        u'бот' : 2212,
        u'инвестиц' : 2213,
        u'пробел' : 2214,
        u'вернут' : 2215,
        u'привет' : 2216,
        u'эффект' : 2217,
        u'занят' : 2218,
        u'вин' : 2219,
        u'травматолог' : 2220,
        u'игрок' : 2221,
        u'хер' : 2222,
        u'мид' : 2223,
        u'вылет' : 2224,
        u'казахста' : 2225,
        u'аним' : 2226,
        u'тоб' : 2227,
        u'копирайт' : 2228,
        u'онлайн' : 2229,
        u'вик' : 2230,
        u'угодн' : 2231,
        u'гнев' : 2232,
        u'десятк' : 2233,
        u'использован' : 2234,
        u'удачн' : 2235,
        u'разгар' : 2236,
        u'перспектив' : 2237,
        u'принцип' : 2238,
        u'вруч' : 2239,
        u'майнинг' : 2240,
        u'сюрприз' : 2241,
        u'дни' : 2242,
        u'дно' : 2243,
        u'выдач' : 2244,
        u'прыжк' : 2245,
        u'характер' : 2246,
        u'напомина' : 2247,
        u'красав' : 2248,
        u'федеральн' : 2249,
        u'утечк' : 2250,
        u'кличк' : 2251,
        u'штат' : 2252,
        u'пожалеет' : 2253,
        u'четырех' : 2254,
        u'бабул' : 2255,
        u'добра' : 2256,
        u'хуев' : 2257,
        u'звонк' : 2258,
        u'кг' : 2259,
        u'нагрузк' : 2260,
        u'остановк' : 2261,
        u'представ' : 2262,
        u'смайлик' : 2263,
        u'санкт' : 2264,
        u'доск' : 2265,
        u'отдыха' : 2266,
        u'окружа' : 2267,
        u'шведск' : 2268,
        u'получен' : 2269,
        u'посад' : 2270,
        u'терракт' : 2271,
        u'берут' : 2272,
        u'долба' : 2273,
        u'остав' : 2274,
        u'космическ' : 2275,
        u'обратн' : 2276,
        u'устройств' : 2277,
        u'кинотеатр' : 2278,
        u'организатор' : 2279,
        u'рекоменд' : 2280,
        u'обманул' : 2281,
        u'краснодар' : 2282,
        u'тор' : 2283,
        u'смог' : 2284,
        u'достойн' : 2285,
        u'жу' : 2286,
        u'нул' : 2287,
        u'обыгра' : 2288,
        u'зарегистрирова' : 2289,
        u'физтех' : 2290,
        u'нафиг' : 2291,
        u'посол' : 2292,
        u'спойлер' : 2293,
        u'снегопад' : 2294,
        u'борис' : 2295,
        u'отлича' : 2296,
        u'поболта' : 2297,
        u'полузащитник' : 2298,
        u'поигра' : 2299,
        u'томатн' : 2300
    }
    
    
    positive_words = {
    u'крут' : 1,
    u'спасиб' : 2,
    u'отличн' : 3,
    u'ур' : 4,
    u'прекрасн' : 5,
    u'приятн' : 6,
    u'добр' : 7,
    u'классн' : 8,
    u'счастлив' : 9,
    u'замечательн' : 10,
    u'обожа' : 11,
    u'здоров' : 12,
    u'счаст' : 13,
    u'выигра' : 14,
    u'поздравля' : 15,
    u'весел' : 16,
    u'радост' : 17,
    u'офиген' : 18,
    u'молодц' : 19,
    u'мил' : 20,
    u'супер' : 21,
    u'шикарн' : 22,
    u'бронз' : 23,
    u'родн' : 24,
    u'солнышк' : 25,
    u'молодец' : 26,
    u'волшебн' : 27,
    u'клев' : 28,
    u'позит' : 29,
    u'порадова' : 30,
    u'горж' : 31,
    u'потряса' : 32,
    u'улыбк' : 33,
    u'поздравлен' : 34,
    u'благодар' : 35,
    u'улыба' : 36,
    u'чудесн' : 37,
    u'брав' : 38,
    u'великолепн' : 39,
    u'уютн' : 40,
    u'внезапн' : 41,
    u'искрен' : 42,
    u'каток' : 43,
    u'восторг' : 44,
    u'юмор' : 45,
    u'эмоц' : 46,
    u'классик' : 47,
    u'кайф' : 48,
    u'плюс' : 49,
    u'атмосферн' : 50,
    u'бан' : 51,
    u'атмосфер' : 52,
    u'сказк' : 53,
    u'волос' : 54,
    u'сгму' : 55,
    u'ката' : 56,
    u'практик' : 57,
    u'сладк' : 58,
    u'поет' : 59,
    u'охренительн' : 60,
    u'катюш' : 61,
    u'божествен' : 62,
    u'исполн' : 63,
    u'татьянин' : 64,
    u'красавец' : 65,
    u'респект' : 66,
    u'водник' : 67,
    u'пример' : 68,
    u'миха' : 69,
    u'благодарн' : 70,
    u'ар' : 71,
    u'воевод' : 72,
    u'потрясающ' : 73,
    u'григор' : 74,
    u'тортик' : 75,
    u'ужин' : 76,
    u'умничк' : 77,
    u'шоколадк' : 78,
    u'пробел' : 79,
    u'красав' : 80,
    u'пожалеет' : 81,
    u'достойн' : 82
    }
    
    negative_words = {
    u'ненавиж' : 1,
    u'плох' : 2,
    u'ужасн' : 3,
    u'блин' : 4,
    u'грустн' : 5,
    u'бес' : 6,
    u'отвратительн' : 7,
    u'туп' : 8,
    u'ужас' : 9,
    u'доста' : 10,
    u'отст' : 11,
    u'говн' : 12,
    u'ненавист' : 13,
    u'чут' : 14,
    u'печал' : 15,
    u'груст' : 16,
    u'хуж' : 17,
    u'печальн' : 18,
    u'блят' : 19,
    u'сук' : 20,
    u'пиздец' : 21,
    u'надоел' : 22,
    u'обидн' : 23,
    u'заболел' : 24,
    u'зла' : 25,
    u'ад' : 26,
    u'дерьм' : 27,
    u'терпет' : 28,
    u'тоск' : 29,
    u'ебан' : 30,
    u'бред' : 31,
    u'позор' : 32,
    u'бляд' : 33,
    u'невыносим' : 34,
    u'учеб' : 35,
    u'хрен' : 36,
    u'разочарова' : 37,
    u'задолба' : 38,
    u'урод' : 39,
    u'мерзк' : 40,
    u'паук' : 41,
    u'уныл' : 42,
    u'паршив' : 43,
    u'нах' : 44,
    u'скуча' : 45,
    u'препод' : 46,
    u'бля' : 47,
    u'сплошн' : 48,
    u'капец' : 49,
    u'плака' : 50,
    u'жалк' : 51,
    u'раздража' : 52,
    u'сожален' : 53,
    u'ви' : 54,
    u'уеба' : 55,
    u'заеба' : 56,
    u'жест' : 57,
    u'дебильн' : 58,
    u'расстро' : 59,
    u'встава' : 60,
    u'гряз' : 61,
    u'интерес' : 62,
    u'уснут' : 63,
    u'противн' : 64,
    u'греба' : 65,
    u'чертов' : 66,
    u'херов' : 67,
    u'идиотизм' : 68,
    u'настольк' : 69,
    u'блеа' : 70,
    u'худш' : 71,
    u'ху' : 72,
    u'проигра' : 73,
    u'гад' : 74,
    u'угнета' : 75,
    u'хренов' : 76,
    u'деканат' : 77,
    u'гадк' : 78,
    u'адск' : 79,
    u'лежа' : 80,
    u'жрат' : 81,
    u'жутк' : 82,
    u'мраз' : 83,
    u'еба' : 84,
    u'забыва' : 85,
    u'негат' : 86,
    u'умира' : 87,
    u'скотин' : 88,
    u'идиот' : 89,
    u'безысходн' : 90,
    u'прова' : 91,
    u'медик' : 92,
    u'фу' : 93,
    u'бесполезн' : 94,
    u'колес' : 95,
    u'несправедлив' : 96,
    u'дурацк' : 97,
    u'ха' : 98,
    u'стыдн' : 99,
    u'зачетк' : 100,
    u'порт' : 101,
    u'гребан' : 102,
    u'неприятн' : 103,
    u'сверл' : 104,
    u'дерьмов' : 105,
    u'пздц' : 106,
    u'кончен' : 107,
    u'сран' : 108,
    u'тлен' : 109,
    u'привыкнут' : 110,
    u'кретин' : 111,
    u'поликлиник' : 112,
    u'хуев' : 113,
    u'берут' : 114,
    u'долба' : 115,
    u'жу' : 116,
    u'нафиг' : 117
    }
    
    neutral_words = {
    u'украин' : 1,
    u'крым' : 2,
    u'российск' : 3,
    u'путин' : 4,
    u'сша' : 5,
    u'президент' : 6,
    u'будут' : 7,
    u'возможн' : 8,
    u'владимир' : 9,
    u'сайт' : 10,
    u'центр' : 11,
    u'журналист' : 12,
    u'стат' : 13,
    u'украинск' : 14,
    u'доллар' : 15,
    u'тысяч' : 16,
    u'бел' : 17,
    u'запрет' : 18,
    u'област' : 19,
    u'правительств' : 20,
    u'дан' : 21,
    u'миллион' : 22,
    u'активн' : 23,
    u'официальн' : 24,
    u'министр' : 25,
    u'регион' : 26,
    u'футбол' : 27,
    u'бизнес' : 28,
    u'сми' : 29,
    u'помощ' : 30,
    u'номер' : 31,
    u'референдум' : 32,
    u'глав' : 33,
    u'заяв' : 34,
    u'евген' : 35,
    u'пост' : 36,
    u'петербург' : 37,
    u'выбор' : 38,
    u'рассказа' : 39,
    u'пораньш' : 40,
    u'явля' : 41,
    u'известн' : 42,
    u'предлага' : 43,
    u'премьер' : 44,
    u'митинг' : 45,
    u'призна' : 46,
    u'доктор' : 47,
    u'паралимпиад' : 48,
    u'интерв' : 49,
    u'обычн' : 50,
    u'воен' : 51,
    u'млн' : 52,
    u'учен' : 53,
    u'назва' : 54,
    u'разбира' : 55,
    u'служб' : 56,
    u'международн' : 57,
    u'тип' : 58,
    u'выйдет' : 59,
    u'проверя' : 60,
    u'умер' : 61,
    u'присоединен' : 62,
    u'бывш' : 63,
    u'обсужда' : 64,
    u'попрос' : 65,
    u'рейтинг' : 66,
    u'планир' : 67,
    u'конференц' : 68,
    u'фестивал' : 69,
    u'губернатор' : 70,
    u'конфликт' : 71,
    u'ворот' : 72,
    u'станет' : 73,
    u'герман' : 74,
    u'кольц' : 75,
    u'книжк' : 76,
    u'жертв' : 77,
    u'япон' : 78,
    u'снача' : 79,
    u'ге' : 80,
    u'москвич' : 81,
    u'пользовател' : 82,
    u'состо' : 83,
    u'вход' : 84,
    u'баз' : 85,
    u'север' : 86,
    u'жител' : 87,
    u'сериа' : 88,
    u'автомобил' : 89,
    u'прем' : 90,
    u'погибл' : 91,
    u'национальн' : 92,
    u'обрат' : 93,
    u'акц' : 94,
    u'евр' : 95,
    u'наук' : 96,
    u'полиц' : 97,
    u'оон' : 98,
    u'назнач' : 99,
    u'хоккейн' : 100,
    u'запуст' : 101,
    u'стартап' : 102,
    u'произошл' : 103,
    u'севастопол' : 104,
    u'крупн' : 105,
    u'ходорковск' : 106,
    u'живет' : 107,
    u'нью' : 108,
    u'посмотрет' : 109,
    u'обам' : 110,
    u'задержа' : 111,
    u'влюблен' : 112,
    u'фонд' : 113,
    u'дальн' : 114,
    u'хакер' : 115,
    u'полицейск' : 116,
    u'восток' : 117,
    u'науч' : 118,
    u'телевизор' : 119,
    u'слух' : 120,
    u'миров' : 121,
    u'заявлен' : 122,
    u'войск' : 123,
    u'паралимпийск' : 124,
    u'попробова' : 125,
    u'сотрудник' : 126,
    u'сладост' : 127,
    u'парт' : 128,
    u'мэр' : 129,
    u'миллиард' : 130,
    u'борот' : 131,
    u'ул' : 132,
    u'социальн' : 133,
    u'землетрясен' : 134,
    u'школьник' : 135,
    u'биткоин' : 136,
    u'сист' : 137,
    u'уезжа' : 138,
    u'википед' : 139,
    u'провер' : 140,
    u'балет' : 141,
    u'йорк' : 142,
    u'нарисова' : 143,
    u'зон' : 144,
    u'уйт' : 145,
    u'подготовк' : 146,
    u'независим' : 147,
    u'ток' : 148,
    u'популярн' : 149,
    u'комплект' : 150,
    u'госдум' : 151,
    u'обязан' : 152,
    u'безопасн' : 153,
    u'код' : 154,
    u'авар' : 155,
    u'должност' : 156,
    u'уголовн' : 157,
    u'кружевн' : 158,
    u'модел' : 159,
    u'ярославл' : 160,
    u'сибир' : 161,
    u'павел' : 162,
    u'великобритан' : 163,
    u'прогресс' : 164,
    u'нарушен' : 165,
    u'индекс' : 166,
    u'студ' : 167,
    u'бренд' : 168,
    u'выплат' : 169,
    u'размещен' : 170,
    u'переста' : 171,
    u'телекана' : 172,
    u'участник' : 173,
    u'выкуп' : 174,
    u'столов' : 175,
    u'богат' : 176,
    u'переговор' : 177,
    u'ссылк' : 178,
    u'п' : 179,
    u'верн' : 180,
    u'восьм' : 181,
    u'начал' : 182,
    u'обща' : 183,
    u'современ' : 184,
    u'прийт' : 185,
    u'париж' : 186,
    u'д' : 187,
    u'черноморск' : 188,
    u'дат' : 189,
    u'франц' : 190,
    u'шаг' : 191,
    u'канал' : 192,
    u'поспа' : 193,
    u'политическ' : 194,
    u'заработа' : 195,
    u'совещан' : 196,
    u'выпуск' : 197,
    u'призва' : 198,
    u'жираф' : 199,
    u'отозва' : 200,
    u'медведев' : 201,
    u'коллег' : 202,
    u'длин' : 203,
    u'ищ' : 204,
    u'водк' : 205,
    u'гаджет' : 206,
    u'процессор' : 207,
    u'инач' : 208,
    u'например' : 209,
    u'резолюц' : 210,
    u'постро' : 211,
    u'бота' : 212,
    u'заблокирова' : 213,
    u'обществен' : 214,
    u'сир' : 215,
    u'груз' : 216,
    u'обвиня' : 217,
    u'пространств' : 218,
    u'рассужда' : 219,
    u'олег' : 220,
    u'остров' : 221,
    u'назначен' : 222,
    u'дорожк' : 223,
    u'порядок' : 224,
    u'камер' : 225,
    u'представител' : 226,
    u'можеш' : 227,
    u'планшет' : 228,
    u'коп' : 229,
    u'гражда' : 230,
    u'возглав' : 231,
    u'японц' : 232,
    u'робот' : 233,
    u'вертолет' : 234,
    u'направ' : 235,
    u'хо' : 236,
    u'колон' : 237,
    u'мчс' : 238,
    u'инвестицион' : 239,
    u'зарубежн' : 240,
    u'рейс' : 241,
    u'приравня' : 242,
    u'содержан' : 243,
    u'реж' : 244,
    u'набор' : 245,
    u'веб' : 246,
    u'моментальн' : 247,
    u'государствен' : 248,
    u'бен' : 249,
    u'наград' : 250,
    u'захват' : 251,
    u'посольств' : 252,
    u'инвестор' : 253,
    u'уничтож' : 254,
    u'оформ' : 255,
    u'организова' : 256,
    u'трамплин' : 257,
    u'собянин' : 258,
    u'челс' : 259,
    u'гроз' : 260,
    u'технолог' : 261,
    u'ля' : 262,
    u'хран' : 263,
    u'националист' : 264,
    u'возьмет' : 265,
    u'гагарин' : 266,
    u'еврейск' : 267,
    u'нижн' : 268,
    u'ма' : 269,
    u'столиц' : 270,
    u'калифорн' : 271,
    u'озер' : 272,
    u'коньяк' : 273,
    u'уязвим' : 274,
    u'проверк' : 275,
    u'заседан' : 276,
    u'подума' : 277,
    u'простот' : 278,
    u'отказа' : 279,
    u'покажут' : 280,
    u'тус' : 281,
    u'происход' : 282,
    u'киевск' : 283,
    u'рынок' : 284,
    u'намерен' : 285,
    u'разыгра' : 286,
    u'автоматическ' : 287,
    u'сдает' : 288,
    u'ру' : 289,
    u'ри' : 290,
    u'учительниц' : 291,
    u'сервер' : 292,
    u'сочинск' : 293,
    u'диалог' : 294,
    u'кита' : 295,
    u'стокгольм' : 296,
    u'кругл' : 297,
    u'стан' : 298,
    u'ящик' : 299,
    u'браузер' : 300,
    u'повест' : 301,
    u'сут' : 302,
    u'дополнен' : 303,
    u'принят' : 304,
    u'итак' : 305,
    u'коррупц' : 306,
    u'федерац' : 307,
    u'болгарск' : 308,
    u'ск' : 309,
    u'отключен' : 310,
    u'пропа' : 311,
    u'приз' : 312,
    u'ласков' : 313,
    u'художествен' : 314,
    u'деятельн' : 315,
    u'мюзикл' : 316,
    u'шапк' : 317,
    u'фолловер' : 318,
    u'аз' : 319,
    u'научн' : 320,
    u'чиновник' : 321,
    u'ясност' : 322,
    u'мвд' : 323,
    u'вс' : 324,
    u'бах' : 325,
    u'мак' : 326,
    u'введ' : 327,
    u'активист' : 328,
    u'симулятор' : 329,
    u'факт' : 330,
    u'наркотик' : 331,
    u'легитимн' : 332,
    u'масс' : 333,
    u'мок' : 334,
    u'андре' : 335,
    u'братск' : 336,
    u'границ' : 337,
    u'видн' : 338,
    u'создава' : 339,
    u'республик' : 340,
    u'передума' : 341,
    u'купл' : 342,
    u'охра' : 343,
    u'освобод' : 344,
    u'бот' : 345,
    u'инвестиц' : 346,
    u'занят' : 347,
    u'игрок' : 348,
    u'мид' : 349,
    u'угодн' : 350,
    u'использован' : 351,
    u'вруч' : 352,
    u'майнинг' : 353,
    u'выдач' : 354,
    u'прыжк' : 355,
    u'напомина' : 356,
    u'федеральн' : 357,
    u'утечк' : 358,
    u'кличк' : 359,
    u'четырех' : 360,
    u'нагрузк' : 361,
    u'санкт' : 362,
    u'шведск' : 363,
    u'посад' : 364,
    u'терракт' : 365,
    u'космическ' : 366,
    u'обыгра' : 367,
    u'зарегистрирова' : 368,
    u'посол' : 369,
    u'снегопад' : 370,
    u'полузащитник' : 371 
    }
    

    russian_stemmer = SnowballStemmer('russian')    #выбор русского языка для извлечения корня
    clf_poly2 = svm.SVC(kernel = "poly", degree = 2)
    forest = RandomForestClassifier(n_estimators = 1000, n_jobs = 4) 
    
    #constructor (optional)
    def __init__(self):
        None


    #trainer of classifier (mandatory)
    def train(self, training_corpus): 
        
        #Filling vocabularies
        #...
        
        #TARGET
        target = [self.polarity_to_num(x['polarity']) for x in training_corpus]
        #TRAIN 
        train = zeros( (len(training_corpus),self.VOCABULARY_LEN), dtype=int16 )
        for  i in range(0,len(training_corpus)): 
            #Normolizing
            normolized_text = '' 
            for l in training_corpus[i].get('text'):
                #print l
                #print l.isalpha() 
                if (l in [' ','!']) or (l.lower() in u'абвгдеёжзийклмнопрстуфхцчшщъыьэюя'):#[' ',',','.','!','*'])):
                    normolized_text += l.lower()
                else:
                    normolized_text = normolized_text + ' '   
                    #удалять повторы
            #print  normolized_text       
            
            #Fill train[i]        
            tokens = nltk.word_tokenize(normolized_text)
            for word in tokens:
                word = self.russian_stemmer.stem(word)
                if self.vocabulary.has_key(word):
                    train[i][self.vocabulary[word]] += 1
                #else:
                    #print word    
                    #print self.vocabulary[word]
            #print normolized_text
            #print train[i]   
            
        #print train
        #for x in training_corpus: print x['text']
        #print target  
        
        
        #Training proceed
        #self.clf_poly2.fit(train, target)
        self.forest.fit(train, target)
        #print 'Обучили'
        
    #returns sentiment score of input text (mandatory)
    def getClasses(self, texts):
        output = []
        
        #static analyze + normalization    
        for x in texts:
            test = zeros(len(self.vocabulary), dtype=int16 ) 
            
            opened = 0
            closed = 0
            symb1 = 0
            symb2 = 0
            
            normolized_text = '' 
            for l in x:#.decode('utf-8'):
                if l == ')':
                    opened = opened + 1
                if l == '(':
                    closed = closed + 1
                if l == '^':
                    symb1 = symb1 + 1
                if l == u'♥':
                    symb2 = symb2 + 1   
                    
                if (l in [' ','!']) or (l.lower() in u'абвгдеёжзийклмнопрстуфхцчшщъыьэюя'):#[' ',',','.','!','*'])):
                    normolized_text += l.lower()  
                    #удалять повторы 
                else:
                    normolized_text = normolized_text + ' '
            #print normolized_text              
            #print opened, ' ', closed, ' ', x
            if ((opened > 0) and (closed == 0)) or (symb1 == 2) or (symb2 > 0):
                output.append('positive') 
            else:
                if (opened == 0) and (closed > 0):
                    output.append('negative')  
                else:
                    pos = 0
                    neg = 0
                    neu = 0
                    tokens = nltk.word_tokenize(normolized_text)
                    for word in tokens:
                        word = self.russian_stemmer.stem(word) 
                        if self.vocabulary.has_key(word):
                            test[self.vocabulary[word]] += 1
                        if word in self.positive_words:
                            pos += 1
                        if word in self.negative_words:
                            neg += 1
                        if word in self.neutral_words:
                            neu += 1
                    if (pos > 0) and (neg == 0) and (neu == 0):
                        output.append('positive') 
                    elif (pos == 0) and (neg > 0) and (neu == 0):
                        output.append('negative') 
                    elif (pos == 0) and (neg == 0) and (neu > 0):
                        output.append('neutral')    
                    else:
                        #print normolized_text
                        #print test  
                        #print self.clf_poly2.predict(test)
                        #output.append(self.num_to_polarity(self.clf_poly2.predict(test))) #append('neutral') 
                        output.append(self.num_to_polarity(self.forest.predict(test))) #append('neutral') 

        
        return output
    
  
                   
    def polarity_to_num(self, polarity):  
        if polarity == 'negative':
            return -1
        if polarity == 'neutral':
            return 0
        if polarity == 'positive':
            return 1
     
    def num_to_polarity(self, num):  
        if num == -1:
            return 'negative'
        if num == 0:
            return 'neutral'
        if num == 1:
            return 'positive'




'''
if __name__ == "__main__":          
    sa = SentimentAnalyzer()
    
    jsObj=open("tweets.json", "r")     
    pObj=json.load(jsObj) 
    jsObj.close()   

    
    
    ROCtrain, ROCtest = cross_validation.train_test_split(pObj, test_size=0.10) 
    
    sa.train(ROCtrain);
    
    #print len(ROCtrain), len(ROCtest)
    print sa.getClasses([u'Хорошо!',u'Уехал к родным. Как же хорошо будет всех увидеть!'])
 
    
    res = sa.getClasses([x['text'] for x in ROCtest])
    print res
   
    #print ROCtest['polarity']
    
    o = 0
    for x in range(0, len(ROCtest)-1):
        
        if res[x] == ROCtest[x].get('polarity'):
            o+=1
        else:
            #print ROCtest[x].get('text')
            print res[x], ROCtest[x].get('polarity')  
        
    print len(ROCtest), '//', o, o*1.0/len(ROCtest)
    '''
    #print ROCtestTRG
    
    #'''    
    
    
    
'''
    vocabulary = {}
    for x in pObj:
        if x['polarity'] == 'negative':   #1 == 1:#
            normolized_text = '' 
            normolized_text2 = '' 
            for l in x['text']:
                if (l.isalpha() or (l in [' ','!'])) and (l.lower() not in 'abcdefghijklmnopqrstuvwxyz'):#[' ',',','.','!','*'])):
                        normolized_text = normolized_text + l
            #print normolized_text 
            tokens = nltk.word_tokenize(normolized_text)
            for word in tokens:
                    word = sa.russian_stemmer.stem(word)
                    normolized_text2 = normolized_text2 + word +' '  
                    if word in vocabulary:
                        vocabulary[word] += 1
                    else:
                        vocabulary[word] = 1    
            #print normolized_text2    
            #train_text.append(normolized_text2)
    #print vocabulary
    i = 0
    #print '['
    for w in sorted(vocabulary, key=vocabulary.get, reverse=True):
        print w#vocabulary[w]
        #if i < 500:#self.VOCABULARY_LEN:
            #print "u'%s' :"%w, "%d,"%i#, vocabulary[w]
            #i += 1
    #print ']'    
    #'''    
